# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: schedule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='schedule.proto',
  package='schedule',
  syntax='proto3',
  serialized_options=_b('\n\033com.supremainc.sdk.scheduleP\001Z\030biostar/service/schedule'),
  serialized_pb=_b('\n\x0eschedule.proto\x12\x08schedule\x1a\terr.proto\"\xa7\x01\n\x0cScheduleInfo\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12&\n\x05\x64\x61ily\x18\x03 \x01(\x0b\x32\x17.schedule.DailySchedule\x12(\n\x06weekly\x18\x04 \x01(\x0b\x32\x18.schedule.WeeklySchedule\x12+\n\x08holidays\x18\x05 \x03(\x0b\x32\x19.schedule.HolidaySchedule\"4\n\x0b\x44\x61ySchedule\x12%\n\x07periods\x18\x01 \x03(\x0b\x32\x14.schedule.TimePeriod\"0\n\nTimePeriod\x12\x11\n\tstartTime\x18\x01 \x01(\x05\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\x05\"=\n\x0eWeeklySchedule\x12+\n\x0c\x64\x61ySchedules\x18\x01 \x03(\x0b\x32\x15.schedule.DaySchedule\"O\n\rDailySchedule\x12\x11\n\tstartDate\x18\x01 \x01(\r\x12+\n\x0c\x64\x61ySchedules\x18\x02 \x03(\x0b\x32\x15.schedule.DaySchedule\"N\n\x0fHolidaySchedule\x12\x0f\n\x07groupID\x18\x01 \x01(\r\x12*\n\x0b\x64\x61ySchedule\x18\x02 \x01(\x0b\x32\x15.schedule.DaySchedule\"M\n\x0cHolidayGroup\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12#\n\x08holidays\x18\x03 \x03(\x0b\x32\x11.schedule.Holiday\"H\n\x07Holiday\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\r\x12/\n\nrecurrence\x18\x02 \x01(\x0e\x32\x1b.schedule.HolidayRecurrence\"\"\n\x0eGetListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"<\n\x0fGetListResponse\x12)\n\tschedules\x18\x01 \x03(\x0b\x32\x16.schedule.ScheduleInfo\"I\n\nAddRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12)\n\tschedules\x18\x02 \x03(\x0b\x32\x16.schedule.ScheduleInfo\"\r\n\x0b\x41\x64\x64Response\"O\n\x0f\x41\x64\x64MultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12)\n\tschedules\x18\x02 \x03(\x0b\x32\x16.schedule.ScheduleInfo\"<\n\x10\x41\x64\x64MultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"6\n\rDeleteRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x13\n\x0bscheduleIDs\x18\x02 \x03(\r\"\x10\n\x0e\x44\x65leteResponse\"<\n\x12\x44\x65leteMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x13\n\x0bscheduleIDs\x18\x02 \x03(\r\"?\n\x13\x44\x65leteMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"$\n\x10\x44\x65leteAllRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x13\n\x11\x44\x65leteAllResponse\"*\n\x15\x44\x65leteAllMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"B\n\x16\x44\x65leteAllMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\")\n\x15GetHolidayListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"@\n\x16GetHolidayListResponse\x12&\n\x06groups\x18\x01 \x03(\x0b\x32\x16.schedule.HolidayGroup\"M\n\x11\x41\x64\x64HolidayRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\x06groups\x18\x02 \x03(\x0b\x32\x16.schedule.HolidayGroup\"\x14\n\x12\x41\x64\x64HolidayResponse\"S\n\x16\x41\x64\x64HolidayMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12&\n\x06groups\x18\x02 \x03(\x0b\x32\x16.schedule.HolidayGroup\"C\n\x17\x41\x64\x64HolidayMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\":\n\x14\x44\x65leteHolidayRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"\x17\n\x15\x44\x65leteHolidayResponse\"@\n\x19\x44\x65leteHolidayMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"F\n\x1a\x44\x65leteHolidayMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"+\n\x17\x44\x65leteAllHolidayRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1a\n\x18\x44\x65leteAllHolidayResponse\"1\n\x1c\x44\x65leteAllHolidayMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"I\n\x1d\x44\x65leteAllHolidayMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\\\n\x11HolidayRecurrence\x12\x10\n\x0c\x44O_NOT_RECUR\x10\x00\x12\x10\n\x0cRECUR_YEARLY\x10\x01\x12\x11\n\rRECUR_MONTHLY\x10\x02\x12\x10\n\x0cRECUR_WEEKLY\x10\x03\x32\xd3\x08\n\x08Schedule\x12>\n\x07GetList\x12\x18.schedule.GetListRequest\x1a\x19.schedule.GetListResponse\x12\x32\n\x03\x41\x64\x64\x12\x14.schedule.AddRequest\x1a\x15.schedule.AddResponse\x12\x41\n\x08\x41\x64\x64Multi\x12\x19.schedule.AddMultiRequest\x1a\x1a.schedule.AddMultiResponse\x12;\n\x06\x44\x65lete\x12\x17.schedule.DeleteRequest\x1a\x18.schedule.DeleteResponse\x12J\n\x0b\x44\x65leteMulti\x12\x1c.schedule.DeleteMultiRequest\x1a\x1d.schedule.DeleteMultiResponse\x12\x44\n\tDeleteAll\x12\x1a.schedule.DeleteAllRequest\x1a\x1b.schedule.DeleteAllResponse\x12S\n\x0e\x44\x65leteAllMulti\x12\x1f.schedule.DeleteAllMultiRequest\x1a .schedule.DeleteAllMultiResponse\x12S\n\x0eGetHolidayList\x12\x1f.schedule.GetHolidayListRequest\x1a .schedule.GetHolidayListResponse\x12G\n\nAddHoliday\x12\x1b.schedule.AddHolidayRequest\x1a\x1c.schedule.AddHolidayResponse\x12V\n\x0f\x41\x64\x64HolidayMulti\x12 .schedule.AddHolidayMultiRequest\x1a!.schedule.AddHolidayMultiResponse\x12P\n\rDeleteHoliday\x12\x1e.schedule.DeleteHolidayRequest\x1a\x1f.schedule.DeleteHolidayResponse\x12_\n\x12\x44\x65leteHolidayMulti\x12#.schedule.DeleteHolidayMultiRequest\x1a$.schedule.DeleteHolidayMultiResponse\x12Y\n\x10\x44\x65leteAllHoliday\x12!.schedule.DeleteAllHolidayRequest\x1a\".schedule.DeleteAllHolidayResponse\x12h\n\x15\x44\x65leteAllHolidayMulti\x12&.schedule.DeleteAllHolidayMultiRequest\x1a\'.schedule.DeleteAllHolidayMultiResponseB9\n\x1b\x63om.supremainc.sdk.scheduleP\x01Z\x18\x62iostar/service/scheduleb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_HOLIDAYRECURRENCE = _descriptor.EnumDescriptor(
  name='HolidayRecurrence',
  full_name='schedule.HolidayRecurrence',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_RECUR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECUR_YEARLY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECUR_MONTHLY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECUR_WEEKLY', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2179,
  serialized_end=2271,
)
_sym_db.RegisterEnumDescriptor(_HOLIDAYRECURRENCE)

HolidayRecurrence = enum_type_wrapper.EnumTypeWrapper(_HOLIDAYRECURRENCE)
DO_NOT_RECUR = 0
RECUR_YEARLY = 1
RECUR_MONTHLY = 2
RECUR_WEEKLY = 3



_SCHEDULEINFO = _descriptor.Descriptor(
  name='ScheduleInfo',
  full_name='schedule.ScheduleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='schedule.ScheduleInfo.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='schedule.ScheduleInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daily', full_name='schedule.ScheduleInfo.daily', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weekly', full_name='schedule.ScheduleInfo.weekly', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='holidays', full_name='schedule.ScheduleInfo.holidays', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=207,
)


_DAYSCHEDULE = _descriptor.Descriptor(
  name='DaySchedule',
  full_name='schedule.DaySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='periods', full_name='schedule.DaySchedule.periods', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=261,
)


_TIMEPERIOD = _descriptor.Descriptor(
  name='TimePeriod',
  full_name='schedule.TimePeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='schedule.TimePeriod.startTime', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='schedule.TimePeriod.endTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=311,
)


_WEEKLYSCHEDULE = _descriptor.Descriptor(
  name='WeeklySchedule',
  full_name='schedule.WeeklySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='daySchedules', full_name='schedule.WeeklySchedule.daySchedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=374,
)


_DAILYSCHEDULE = _descriptor.Descriptor(
  name='DailySchedule',
  full_name='schedule.DailySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startDate', full_name='schedule.DailySchedule.startDate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daySchedules', full_name='schedule.DailySchedule.daySchedules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=455,
)


_HOLIDAYSCHEDULE = _descriptor.Descriptor(
  name='HolidaySchedule',
  full_name='schedule.HolidaySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupID', full_name='schedule.HolidaySchedule.groupID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daySchedule', full_name='schedule.HolidaySchedule.daySchedule', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=535,
)


_HOLIDAYGROUP = _descriptor.Descriptor(
  name='HolidayGroup',
  full_name='schedule.HolidayGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='schedule.HolidayGroup.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='schedule.HolidayGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='holidays', full_name='schedule.HolidayGroup.holidays', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=614,
)


_HOLIDAY = _descriptor.Descriptor(
  name='Holiday',
  full_name='schedule.Holiday',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='schedule.Holiday.date', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recurrence', full_name='schedule.Holiday.recurrence', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=688,
)


_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='schedule.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.GetListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=690,
  serialized_end=724,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='schedule.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='schedule.GetListResponse.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=786,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='schedule.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.AddRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedules', full_name='schedule.AddRequest.schedules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=861,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='schedule.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=876,
)


_ADDMULTIREQUEST = _descriptor.Descriptor(
  name='AddMultiRequest',
  full_name='schedule.AddMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.AddMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedules', full_name='schedule.AddMultiRequest.schedules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=957,
)


_ADDMULTIRESPONSE = _descriptor.Descriptor(
  name='AddMultiResponse',
  full_name='schedule.AddMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.AddMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1019,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='schedule.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleIDs', full_name='schedule.DeleteRequest.scheduleIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1075,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='schedule.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1077,
  serialized_end=1093,
)


_DELETEMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteMultiRequest',
  full_name='schedule.DeleteMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleIDs', full_name='schedule.DeleteMultiRequest.scheduleIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1155,
)


_DELETEMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteMultiResponse',
  full_name='schedule.DeleteMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1220,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='schedule.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteAllRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1258,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='schedule.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1279,
)


_DELETEALLMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllMultiRequest',
  full_name='schedule.DeleteAllMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteAllMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1323,
)


_DELETEALLMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllMultiResponse',
  full_name='schedule.DeleteAllMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteAllMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1325,
  serialized_end=1391,
)


_GETHOLIDAYLISTREQUEST = _descriptor.Descriptor(
  name='GetHolidayListRequest',
  full_name='schedule.GetHolidayListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.GetHolidayListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1434,
)


_GETHOLIDAYLISTRESPONSE = _descriptor.Descriptor(
  name='GetHolidayListResponse',
  full_name='schedule.GetHolidayListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='schedule.GetHolidayListResponse.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1436,
  serialized_end=1500,
)


_ADDHOLIDAYREQUEST = _descriptor.Descriptor(
  name='AddHolidayRequest',
  full_name='schedule.AddHolidayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.AddHolidayRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='schedule.AddHolidayRequest.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1579,
)


_ADDHOLIDAYRESPONSE = _descriptor.Descriptor(
  name='AddHolidayResponse',
  full_name='schedule.AddHolidayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1601,
)


_ADDHOLIDAYMULTIREQUEST = _descriptor.Descriptor(
  name='AddHolidayMultiRequest',
  full_name='schedule.AddHolidayMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.AddHolidayMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='schedule.AddHolidayMultiRequest.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1603,
  serialized_end=1686,
)


_ADDHOLIDAYMULTIRESPONSE = _descriptor.Descriptor(
  name='AddHolidayMultiResponse',
  full_name='schedule.AddHolidayMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.AddHolidayMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=1755,
)


_DELETEHOLIDAYREQUEST = _descriptor.Descriptor(
  name='DeleteHolidayRequest',
  full_name='schedule.DeleteHolidayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteHolidayRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='schedule.DeleteHolidayRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1815,
)


_DELETEHOLIDAYRESPONSE = _descriptor.Descriptor(
  name='DeleteHolidayResponse',
  full_name='schedule.DeleteHolidayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1817,
  serialized_end=1840,
)


_DELETEHOLIDAYMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteHolidayMultiRequest',
  full_name='schedule.DeleteHolidayMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteHolidayMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='schedule.DeleteHolidayMultiRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1906,
)


_DELETEHOLIDAYMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteHolidayMultiResponse',
  full_name='schedule.DeleteHolidayMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteHolidayMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1908,
  serialized_end=1978,
)


_DELETEALLHOLIDAYREQUEST = _descriptor.Descriptor(
  name='DeleteAllHolidayRequest',
  full_name='schedule.DeleteAllHolidayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteAllHolidayRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1980,
  serialized_end=2023,
)


_DELETEALLHOLIDAYRESPONSE = _descriptor.Descriptor(
  name='DeleteAllHolidayResponse',
  full_name='schedule.DeleteAllHolidayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2051,
)


_DELETEALLHOLIDAYMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllHolidayMultiRequest',
  full_name='schedule.DeleteAllHolidayMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteAllHolidayMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2102,
)


_DELETEALLHOLIDAYMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllHolidayMultiResponse',
  full_name='schedule.DeleteAllHolidayMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteAllHolidayMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2104,
  serialized_end=2177,
)

_SCHEDULEINFO.fields_by_name['daily'].message_type = _DAILYSCHEDULE
_SCHEDULEINFO.fields_by_name['weekly'].message_type = _WEEKLYSCHEDULE
_SCHEDULEINFO.fields_by_name['holidays'].message_type = _HOLIDAYSCHEDULE
_DAYSCHEDULE.fields_by_name['periods'].message_type = _TIMEPERIOD
_WEEKLYSCHEDULE.fields_by_name['daySchedules'].message_type = _DAYSCHEDULE
_DAILYSCHEDULE.fields_by_name['daySchedules'].message_type = _DAYSCHEDULE
_HOLIDAYSCHEDULE.fields_by_name['daySchedule'].message_type = _DAYSCHEDULE
_HOLIDAYGROUP.fields_by_name['holidays'].message_type = _HOLIDAY
_HOLIDAY.fields_by_name['recurrence'].enum_type = _HOLIDAYRECURRENCE
_GETLISTRESPONSE.fields_by_name['schedules'].message_type = _SCHEDULEINFO
_ADDREQUEST.fields_by_name['schedules'].message_type = _SCHEDULEINFO
_ADDMULTIREQUEST.fields_by_name['schedules'].message_type = _SCHEDULEINFO
_ADDMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GETHOLIDAYLISTRESPONSE.fields_by_name['groups'].message_type = _HOLIDAYGROUP
_ADDHOLIDAYREQUEST.fields_by_name['groups'].message_type = _HOLIDAYGROUP
_ADDHOLIDAYMULTIREQUEST.fields_by_name['groups'].message_type = _HOLIDAYGROUP
_ADDHOLIDAYMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEHOLIDAYMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLHOLIDAYMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['ScheduleInfo'] = _SCHEDULEINFO
DESCRIPTOR.message_types_by_name['DaySchedule'] = _DAYSCHEDULE
DESCRIPTOR.message_types_by_name['TimePeriod'] = _TIMEPERIOD
DESCRIPTOR.message_types_by_name['WeeklySchedule'] = _WEEKLYSCHEDULE
DESCRIPTOR.message_types_by_name['DailySchedule'] = _DAILYSCHEDULE
DESCRIPTOR.message_types_by_name['HolidaySchedule'] = _HOLIDAYSCHEDULE
DESCRIPTOR.message_types_by_name['HolidayGroup'] = _HOLIDAYGROUP
DESCRIPTOR.message_types_by_name['Holiday'] = _HOLIDAY
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['AddMultiRequest'] = _ADDMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddMultiResponse'] = _ADDMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['DeleteMultiRequest'] = _DELETEMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteMultiResponse'] = _DELETEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllMultiRequest'] = _DELETEALLMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllMultiResponse'] = _DELETEALLMULTIRESPONSE
DESCRIPTOR.message_types_by_name['GetHolidayListRequest'] = _GETHOLIDAYLISTREQUEST
DESCRIPTOR.message_types_by_name['GetHolidayListResponse'] = _GETHOLIDAYLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddHolidayRequest'] = _ADDHOLIDAYREQUEST
DESCRIPTOR.message_types_by_name['AddHolidayResponse'] = _ADDHOLIDAYRESPONSE
DESCRIPTOR.message_types_by_name['AddHolidayMultiRequest'] = _ADDHOLIDAYMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddHolidayMultiResponse'] = _ADDHOLIDAYMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteHolidayRequest'] = _DELETEHOLIDAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteHolidayResponse'] = _DELETEHOLIDAYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteHolidayMultiRequest'] = _DELETEHOLIDAYMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteHolidayMultiResponse'] = _DELETEHOLIDAYMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllHolidayRequest'] = _DELETEALLHOLIDAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllHolidayResponse'] = _DELETEALLHOLIDAYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllHolidayMultiRequest'] = _DELETEALLHOLIDAYMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllHolidayMultiResponse'] = _DELETEALLHOLIDAYMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['HolidayRecurrence'] = _HOLIDAYRECURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScheduleInfo = _reflection.GeneratedProtocolMessageType('ScheduleInfo', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEINFO,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.ScheduleInfo)
  ))
_sym_db.RegisterMessage(ScheduleInfo)

DaySchedule = _reflection.GeneratedProtocolMessageType('DaySchedule', (_message.Message,), dict(
  DESCRIPTOR = _DAYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DaySchedule)
  ))
_sym_db.RegisterMessage(DaySchedule)

TimePeriod = _reflection.GeneratedProtocolMessageType('TimePeriod', (_message.Message,), dict(
  DESCRIPTOR = _TIMEPERIOD,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.TimePeriod)
  ))
_sym_db.RegisterMessage(TimePeriod)

WeeklySchedule = _reflection.GeneratedProtocolMessageType('WeeklySchedule', (_message.Message,), dict(
  DESCRIPTOR = _WEEKLYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.WeeklySchedule)
  ))
_sym_db.RegisterMessage(WeeklySchedule)

DailySchedule = _reflection.GeneratedProtocolMessageType('DailySchedule', (_message.Message,), dict(
  DESCRIPTOR = _DAILYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DailySchedule)
  ))
_sym_db.RegisterMessage(DailySchedule)

HolidaySchedule = _reflection.GeneratedProtocolMessageType('HolidaySchedule', (_message.Message,), dict(
  DESCRIPTOR = _HOLIDAYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.HolidaySchedule)
  ))
_sym_db.RegisterMessage(HolidaySchedule)

HolidayGroup = _reflection.GeneratedProtocolMessageType('HolidayGroup', (_message.Message,), dict(
  DESCRIPTOR = _HOLIDAYGROUP,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.HolidayGroup)
  ))
_sym_db.RegisterMessage(HolidayGroup)

Holiday = _reflection.GeneratedProtocolMessageType('Holiday', (_message.Message,), dict(
  DESCRIPTOR = _HOLIDAY,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.Holiday)
  ))
_sym_db.RegisterMessage(Holiday)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

AddMultiRequest = _reflection.GeneratedProtocolMessageType('AddMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddMultiRequest)
  ))
_sym_db.RegisterMessage(AddMultiRequest)

AddMultiResponse = _reflection.GeneratedProtocolMessageType('AddMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddMultiResponse)
  ))
_sym_db.RegisterMessage(AddMultiResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

DeleteMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteMultiRequest)

DeleteMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteMultiResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllRequest)
  ))
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllResponse)
  ))
_sym_db.RegisterMessage(DeleteAllResponse)

DeleteAllMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllMultiRequest)

DeleteAllMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllMultiResponse)

GetHolidayListRequest = _reflection.GeneratedProtocolMessageType('GetHolidayListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETHOLIDAYLISTREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetHolidayListRequest)
  ))
_sym_db.RegisterMessage(GetHolidayListRequest)

GetHolidayListResponse = _reflection.GeneratedProtocolMessageType('GetHolidayListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETHOLIDAYLISTRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetHolidayListResponse)
  ))
_sym_db.RegisterMessage(GetHolidayListResponse)

AddHolidayRequest = _reflection.GeneratedProtocolMessageType('AddHolidayRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayRequest)
  ))
_sym_db.RegisterMessage(AddHolidayRequest)

AddHolidayResponse = _reflection.GeneratedProtocolMessageType('AddHolidayResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayResponse)
  ))
_sym_db.RegisterMessage(AddHolidayResponse)

AddHolidayMultiRequest = _reflection.GeneratedProtocolMessageType('AddHolidayMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayMultiRequest)
  ))
_sym_db.RegisterMessage(AddHolidayMultiRequest)

AddHolidayMultiResponse = _reflection.GeneratedProtocolMessageType('AddHolidayMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayMultiResponse)
  ))
_sym_db.RegisterMessage(AddHolidayMultiResponse)

DeleteHolidayRequest = _reflection.GeneratedProtocolMessageType('DeleteHolidayRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayRequest)
  ))
_sym_db.RegisterMessage(DeleteHolidayRequest)

DeleteHolidayResponse = _reflection.GeneratedProtocolMessageType('DeleteHolidayResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayResponse)
  ))
_sym_db.RegisterMessage(DeleteHolidayResponse)

DeleteHolidayMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteHolidayMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteHolidayMultiRequest)

DeleteHolidayMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteHolidayMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteHolidayMultiResponse)

DeleteAllHolidayRequest = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayRequest)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayRequest)

DeleteAllHolidayResponse = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayResponse)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayResponse)

DeleteAllHolidayMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayMultiRequest)

DeleteAllHolidayMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayMultiResponse)


DESCRIPTOR._options = None

_SCHEDULE = _descriptor.ServiceDescriptor(
  name='Schedule',
  full_name='schedule.Schedule',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2274,
  serialized_end=3381,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='schedule.Schedule.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='schedule.Schedule.Add',
    index=1,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddMulti',
    full_name='schedule.Schedule.AddMulti',
    index=2,
    containing_service=None,
    input_type=_ADDMULTIREQUEST,
    output_type=_ADDMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='schedule.Schedule.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMulti',
    full_name='schedule.Schedule.DeleteMulti',
    index=4,
    containing_service=None,
    input_type=_DELETEMULTIREQUEST,
    output_type=_DELETEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='schedule.Schedule.DeleteAll',
    index=5,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllMulti',
    full_name='schedule.Schedule.DeleteAllMulti',
    index=6,
    containing_service=None,
    input_type=_DELETEALLMULTIREQUEST,
    output_type=_DELETEALLMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHolidayList',
    full_name='schedule.Schedule.GetHolidayList',
    index=7,
    containing_service=None,
    input_type=_GETHOLIDAYLISTREQUEST,
    output_type=_GETHOLIDAYLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddHoliday',
    full_name='schedule.Schedule.AddHoliday',
    index=8,
    containing_service=None,
    input_type=_ADDHOLIDAYREQUEST,
    output_type=_ADDHOLIDAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddHolidayMulti',
    full_name='schedule.Schedule.AddHolidayMulti',
    index=9,
    containing_service=None,
    input_type=_ADDHOLIDAYMULTIREQUEST,
    output_type=_ADDHOLIDAYMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteHoliday',
    full_name='schedule.Schedule.DeleteHoliday',
    index=10,
    containing_service=None,
    input_type=_DELETEHOLIDAYREQUEST,
    output_type=_DELETEHOLIDAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteHolidayMulti',
    full_name='schedule.Schedule.DeleteHolidayMulti',
    index=11,
    containing_service=None,
    input_type=_DELETEHOLIDAYMULTIREQUEST,
    output_type=_DELETEHOLIDAYMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllHoliday',
    full_name='schedule.Schedule.DeleteAllHoliday',
    index=12,
    containing_service=None,
    input_type=_DELETEALLHOLIDAYREQUEST,
    output_type=_DELETEALLHOLIDAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllHolidayMulti',
    full_name='schedule.Schedule.DeleteAllHolidayMulti',
    index=13,
    containing_service=None,
    input_type=_DELETEALLHOLIDAYMULTIREQUEST,
    output_type=_DELETEALLHOLIDAYMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCHEDULE)

DESCRIPTOR.services_by_name['Schedule'] = _SCHEDULE

# @@protoc_insertion_point(module_scope)
