# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tenant.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import cert_pb2 as cert__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tenant.proto',
  package='tenant',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.tenantP\001Z\026biostar/service/tenant'),
  serialized_pb=_b('\n\x0ctenant.proto\x12\x06tenant\x1a\ncert.proto\"2\n\nTenantInfo\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x12\n\ngatewayIDs\x18\x02 \x03(\t\"\x10\n\x0eGetListRequest\"$\n\x0fGetListResponse\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"\x1f\n\nGetRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"6\n\x0bGetResponse\x12\'\n\x0btenantInfos\x18\x01 \x03(\x0b\x32\x12.tenant.TenantInfo\"5\n\nAddRequest\x12\'\n\x0btenantInfos\x18\x01 \x03(\x0b\x32\x12.tenant.TenantInfo\"\r\n\x0b\x41\x64\x64Response\"\"\n\rDeleteRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"\x10\n\x0e\x44\x65leteResponse\"9\n\x11\x41\x64\x64GatewayRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x12\n\ngatewayIDs\x18\x02 \x03(\t\"\x14\n\x12\x41\x64\x64GatewayResponse\"<\n\x14\x44\x65leteGatewayRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x12\n\ngatewayIDs\x18\x02 \x03(\t\"\x17\n\x15\x44\x65leteGatewayResponse\"f\n\x18\x43reateCertificateRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x1e\n\x07subject\x18\x02 \x01(\x0b\x32\r.cert.PKIName\x12\x18\n\x10\x65xpireAfterYears\x18\x03 \x01(\x05\"B\n\x19\x43reateCertificateResponse\x12\x12\n\ntenantCert\x18\x01 \x01(\t\x12\x11\n\ttenantKey\x18\x02 \x01(\t\".\n\x19GetIssuanceHistoryRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"\x91\x01\n\x0f\x43\x65rtificateInfo\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x1e\n\x07subject\x18\x02 \x01(\x0b\x32\r.cert.PKIName\x12\x10\n\x08serialNO\x18\x03 \x01(\x03\x12\x11\n\tissueDate\x18\x04 \x01(\x03\x12\x12\n\nexpiryDate\x18\x05 \x01(\x03\x12\x13\n\x0b\x62lacklisted\x18\x06 \x01(\x08\"H\n\x1aGetIssuanceHistoryResponse\x12*\n\tcertInfos\x18\x01 \x03(\x0b\x32\x17.tenant.CertificateInfo\"3\n\x1eGetCertificateBlacklistRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"M\n\x1fGetCertificateBlacklistResponse\x12*\n\tcertInfos\x18\x01 \x03(\x0b\x32\x17.tenant.CertificateInfo\"E\n\x1e\x41\x64\x64\x43\x65rtificateBlacklistRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x11\n\tserialNOs\x18\x02 \x03(\x03\"!\n\x1f\x41\x64\x64\x43\x65rtificateBlacklistResponse\"H\n!DeleteCertificateBlacklistRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x11\n\tserialNOs\x18\x02 \x03(\x03\"$\n\"DeleteCertificateBlacklistResponse2\xf4\x06\n\x06Tenant\x12:\n\x07GetList\x12\x16.tenant.GetListRequest\x1a\x17.tenant.GetListResponse\x12.\n\x03Get\x12\x12.tenant.GetRequest\x1a\x13.tenant.GetResponse\x12.\n\x03\x41\x64\x64\x12\x12.tenant.AddRequest\x1a\x13.tenant.AddResponse\x12\x37\n\x06\x44\x65lete\x12\x15.tenant.DeleteRequest\x1a\x16.tenant.DeleteResponse\x12\x43\n\nAddGateway\x12\x19.tenant.AddGatewayRequest\x1a\x1a.tenant.AddGatewayResponse\x12L\n\rDeleteGateway\x12\x1c.tenant.DeleteGatewayRequest\x1a\x1d.tenant.DeleteGatewayResponse\x12X\n\x11\x43reateCertificate\x12 .tenant.CreateCertificateRequest\x1a!.tenant.CreateCertificateResponse\x12[\n\x12GetIssuanceHistory\x12!.tenant.GetIssuanceHistoryRequest\x1a\".tenant.GetIssuanceHistoryResponse\x12j\n\x17GetCertificateBlacklist\x12&.tenant.GetCertificateBlacklistRequest\x1a\'.tenant.GetCertificateBlacklistResponse\x12j\n\x17\x41\x64\x64\x43\x65rtificateBlacklist\x12&.tenant.AddCertificateBlacklistRequest\x1a\'.tenant.AddCertificateBlacklistResponse\x12s\n\x1a\x44\x65leteCertificateBlacklist\x12).tenant.DeleteCertificateBlacklistRequest\x1a*.tenant.DeleteCertificateBlacklistResponseB5\n\x19\x63om.supremainc.sdk.tenantP\x01Z\x16\x62iostar/service/tenantb\x06proto3')
  ,
  dependencies=[cert__pb2.DESCRIPTOR,])




_TENANTINFO = _descriptor.Descriptor(
  name='TenantInfo',
  full_name='tenant.TenantInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.TenantInfo.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='tenant.TenantInfo.gatewayIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=86,
)


_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='tenant.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=104,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='tenant.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetListResponse.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=142,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='tenant.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=175,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='tenant.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantInfos', full_name='tenant.GetResponse.tenantInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=231,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='tenant.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantInfos', full_name='tenant.AddRequest.tenantInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=286,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='tenant.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=301,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='tenant.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.DeleteRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=337,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='tenant.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=355,
)


_ADDGATEWAYREQUEST = _descriptor.Descriptor(
  name='AddGatewayRequest',
  full_name='tenant.AddGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.AddGatewayRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='tenant.AddGatewayRequest.gatewayIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=414,
)


_ADDGATEWAYRESPONSE = _descriptor.Descriptor(
  name='AddGatewayResponse',
  full_name='tenant.AddGatewayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=436,
)


_DELETEGATEWAYREQUEST = _descriptor.Descriptor(
  name='DeleteGatewayRequest',
  full_name='tenant.DeleteGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.DeleteGatewayRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='tenant.DeleteGatewayRequest.gatewayIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=498,
)


_DELETEGATEWAYRESPONSE = _descriptor.Descriptor(
  name='DeleteGatewayResponse',
  full_name='tenant.DeleteGatewayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=523,
)


_CREATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='CreateCertificateRequest',
  full_name='tenant.CreateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.CreateCertificateRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='tenant.CreateCertificateRequest.subject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expireAfterYears', full_name='tenant.CreateCertificateRequest.expireAfterYears', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=627,
)


_CREATECERTIFICATERESPONSE = _descriptor.Descriptor(
  name='CreateCertificateResponse',
  full_name='tenant.CreateCertificateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantCert', full_name='tenant.CreateCertificateResponse.tenantCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tenantKey', full_name='tenant.CreateCertificateResponse.tenantKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=695,
)


_GETISSUANCEHISTORYREQUEST = _descriptor.Descriptor(
  name='GetIssuanceHistoryRequest',
  full_name='tenant.GetIssuanceHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetIssuanceHistoryRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=743,
)


_CERTIFICATEINFO = _descriptor.Descriptor(
  name='CertificateInfo',
  full_name='tenant.CertificateInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.CertificateInfo.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='tenant.CertificateInfo.subject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNO', full_name='tenant.CertificateInfo.serialNO', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issueDate', full_name='tenant.CertificateInfo.issueDate', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiryDate', full_name='tenant.CertificateInfo.expiryDate', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blacklisted', full_name='tenant.CertificateInfo.blacklisted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=891,
)


_GETISSUANCEHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetIssuanceHistoryResponse',
  full_name='tenant.GetIssuanceHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certInfos', full_name='tenant.GetIssuanceHistoryResponse.certInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=965,
)


_GETCERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='GetCertificateBlacklistRequest',
  full_name='tenant.GetCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetCertificateBlacklistRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1018,
)


_GETCERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='GetCertificateBlacklistResponse',
  full_name='tenant.GetCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certInfos', full_name='tenant.GetCertificateBlacklistResponse.certInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1097,
)


_ADDCERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='AddCertificateBlacklistRequest',
  full_name='tenant.AddCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.AddCertificateBlacklistRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNOs', full_name='tenant.AddCertificateBlacklistRequest.serialNOs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1168,
)


_ADDCERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='AddCertificateBlacklistResponse',
  full_name='tenant.AddCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1203,
)


_DELETECERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='DeleteCertificateBlacklistRequest',
  full_name='tenant.DeleteCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.DeleteCertificateBlacklistRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNOs', full_name='tenant.DeleteCertificateBlacklistRequest.serialNOs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1277,
)


_DELETECERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='DeleteCertificateBlacklistResponse',
  full_name='tenant.DeleteCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1315,
)

_GETRESPONSE.fields_by_name['tenantInfos'].message_type = _TENANTINFO
_ADDREQUEST.fields_by_name['tenantInfos'].message_type = _TENANTINFO
_CREATECERTIFICATEREQUEST.fields_by_name['subject'].message_type = cert__pb2._PKINAME
_CERTIFICATEINFO.fields_by_name['subject'].message_type = cert__pb2._PKINAME
_GETISSUANCEHISTORYRESPONSE.fields_by_name['certInfos'].message_type = _CERTIFICATEINFO
_GETCERTIFICATEBLACKLISTRESPONSE.fields_by_name['certInfos'].message_type = _CERTIFICATEINFO
DESCRIPTOR.message_types_by_name['TenantInfo'] = _TENANTINFO
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['AddGatewayRequest'] = _ADDGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['AddGatewayResponse'] = _ADDGATEWAYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteGatewayRequest'] = _DELETEGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteGatewayResponse'] = _DELETEGATEWAYRESPONSE
DESCRIPTOR.message_types_by_name['CreateCertificateRequest'] = _CREATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['CreateCertificateResponse'] = _CREATECERTIFICATERESPONSE
DESCRIPTOR.message_types_by_name['GetIssuanceHistoryRequest'] = _GETISSUANCEHISTORYREQUEST
DESCRIPTOR.message_types_by_name['CertificateInfo'] = _CERTIFICATEINFO
DESCRIPTOR.message_types_by_name['GetIssuanceHistoryResponse'] = _GETISSUANCEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['GetCertificateBlacklistRequest'] = _GETCERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['GetCertificateBlacklistResponse'] = _GETCERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddCertificateBlacklistRequest'] = _ADDCERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['AddCertificateBlacklistResponse'] = _ADDCERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteCertificateBlacklistRequest'] = _DELETECERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['DeleteCertificateBlacklistResponse'] = _DELETECERTIFICATEBLACKLISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TenantInfo = _reflection.GeneratedProtocolMessageType('TenantInfo', (_message.Message,), dict(
  DESCRIPTOR = _TENANTINFO,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.TenantInfo)
  ))
_sym_db.RegisterMessage(TenantInfo)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

AddGatewayRequest = _reflection.GeneratedProtocolMessageType('AddGatewayRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDGATEWAYREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddGatewayRequest)
  ))
_sym_db.RegisterMessage(AddGatewayRequest)

AddGatewayResponse = _reflection.GeneratedProtocolMessageType('AddGatewayResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDGATEWAYRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddGatewayResponse)
  ))
_sym_db.RegisterMessage(AddGatewayResponse)

DeleteGatewayRequest = _reflection.GeneratedProtocolMessageType('DeleteGatewayRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEGATEWAYREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteGatewayRequest)
  ))
_sym_db.RegisterMessage(DeleteGatewayRequest)

DeleteGatewayResponse = _reflection.GeneratedProtocolMessageType('DeleteGatewayResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEGATEWAYRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteGatewayResponse)
  ))
_sym_db.RegisterMessage(DeleteGatewayResponse)

CreateCertificateRequest = _reflection.GeneratedProtocolMessageType('CreateCertificateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATECERTIFICATEREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.CreateCertificateRequest)
  ))
_sym_db.RegisterMessage(CreateCertificateRequest)

CreateCertificateResponse = _reflection.GeneratedProtocolMessageType('CreateCertificateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATECERTIFICATERESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.CreateCertificateResponse)
  ))
_sym_db.RegisterMessage(CreateCertificateResponse)

GetIssuanceHistoryRequest = _reflection.GeneratedProtocolMessageType('GetIssuanceHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETISSUANCEHISTORYREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetIssuanceHistoryRequest)
  ))
_sym_db.RegisterMessage(GetIssuanceHistoryRequest)

CertificateInfo = _reflection.GeneratedProtocolMessageType('CertificateInfo', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEINFO,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.CertificateInfo)
  ))
_sym_db.RegisterMessage(CertificateInfo)

GetIssuanceHistoryResponse = _reflection.GeneratedProtocolMessageType('GetIssuanceHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETISSUANCEHISTORYRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetIssuanceHistoryResponse)
  ))
_sym_db.RegisterMessage(GetIssuanceHistoryResponse)

GetCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('GetCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCERTIFICATEBLACKLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(GetCertificateBlacklistRequest)

GetCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('GetCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(GetCertificateBlacklistResponse)

AddCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('AddCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDCERTIFICATEBLACKLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(AddCertificateBlacklistRequest)

AddCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('AddCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDCERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(AddCertificateBlacklistResponse)

DeleteCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('DeleteCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETECERTIFICATEBLACKLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(DeleteCertificateBlacklistRequest)

DeleteCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('DeleteCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETECERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(DeleteCertificateBlacklistResponse)


DESCRIPTOR._options = None

_TENANT = _descriptor.ServiceDescriptor(
  name='Tenant',
  full_name='tenant.Tenant',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1318,
  serialized_end=2202,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='tenant.Tenant.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='tenant.Tenant.Get',
    index=1,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='tenant.Tenant.Add',
    index=2,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='tenant.Tenant.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddGateway',
    full_name='tenant.Tenant.AddGateway',
    index=4,
    containing_service=None,
    input_type=_ADDGATEWAYREQUEST,
    output_type=_ADDGATEWAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteGateway',
    full_name='tenant.Tenant.DeleteGateway',
    index=5,
    containing_service=None,
    input_type=_DELETEGATEWAYREQUEST,
    output_type=_DELETEGATEWAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCertificate',
    full_name='tenant.Tenant.CreateCertificate',
    index=6,
    containing_service=None,
    input_type=_CREATECERTIFICATEREQUEST,
    output_type=_CREATECERTIFICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetIssuanceHistory',
    full_name='tenant.Tenant.GetIssuanceHistory',
    index=7,
    containing_service=None,
    input_type=_GETISSUANCEHISTORYREQUEST,
    output_type=_GETISSUANCEHISTORYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCertificateBlacklist',
    full_name='tenant.Tenant.GetCertificateBlacklist',
    index=8,
    containing_service=None,
    input_type=_GETCERTIFICATEBLACKLISTREQUEST,
    output_type=_GETCERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddCertificateBlacklist',
    full_name='tenant.Tenant.AddCertificateBlacklist',
    index=9,
    containing_service=None,
    input_type=_ADDCERTIFICATEBLACKLISTREQUEST,
    output_type=_ADDCERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCertificateBlacklist',
    full_name='tenant.Tenant.DeleteCertificateBlacklist',
    index=10,
    containing_service=None,
    input_type=_DELETECERTIFICATEBLACKLISTREQUEST,
    output_type=_DELETECERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENANT)

DESCRIPTOR.services_by_name['Tenant'] = _TENANT

# @@protoc_insertion_point(module_scope)
