# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import operator_pb2 as operator__pb2


class OperatorStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetList = channel.unary_unary(
        '/operator.Operator/GetList',
        request_serializer=operator__pb2.GetListRequest.SerializeToString,
        response_deserializer=operator__pb2.GetListResponse.FromString,
        )
    self.Add = channel.unary_unary(
        '/operator.Operator/Add',
        request_serializer=operator__pb2.AddRequest.SerializeToString,
        response_deserializer=operator__pb2.AddResponse.FromString,
        )
    self.AddMulti = channel.unary_unary(
        '/operator.Operator/AddMulti',
        request_serializer=operator__pb2.AddMultiRequest.SerializeToString,
        response_deserializer=operator__pb2.AddMultiResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/operator.Operator/Delete',
        request_serializer=operator__pb2.DeleteRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteResponse.FromString,
        )
    self.DeleteMulti = channel.unary_unary(
        '/operator.Operator/DeleteMulti',
        request_serializer=operator__pb2.DeleteMultiRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteMultiResponse.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/operator.Operator/DeleteAll',
        request_serializer=operator__pb2.DeleteAllRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteAllResponse.FromString,
        )
    self.DeleteAllMulti = channel.unary_unary(
        '/operator.Operator/DeleteAllMulti',
        request_serializer=operator__pb2.DeleteAllMultiRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteAllMultiResponse.FromString,
        )


class OperatorServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Add(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_OperatorServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetList': grpc.unary_unary_rpc_method_handler(
          servicer.GetList,
          request_deserializer=operator__pb2.GetListRequest.FromString,
          response_serializer=operator__pb2.GetListResponse.SerializeToString,
      ),
      'Add': grpc.unary_unary_rpc_method_handler(
          servicer.Add,
          request_deserializer=operator__pb2.AddRequest.FromString,
          response_serializer=operator__pb2.AddResponse.SerializeToString,
      ),
      'AddMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddMulti,
          request_deserializer=operator__pb2.AddMultiRequest.FromString,
          response_serializer=operator__pb2.AddMultiResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=operator__pb2.DeleteRequest.FromString,
          response_serializer=operator__pb2.DeleteResponse.SerializeToString,
      ),
      'DeleteMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteMulti,
          request_deserializer=operator__pb2.DeleteMultiRequest.FromString,
          response_serializer=operator__pb2.DeleteMultiResponse.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=operator__pb2.DeleteAllRequest.FromString,
          response_serializer=operator__pb2.DeleteAllResponse.SerializeToString,
      ),
      'DeleteAllMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllMulti,
          request_deserializer=operator__pb2.DeleteAllMultiRequest.FromString,
          response_serializer=operator__pb2.DeleteAllMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'operator.Operator', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
