# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2
from biostarPython.service import system_pb2 as system__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config.proto',
  package='config',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.configP\001Z\026biostar/service/config'),
  serialized_pb=_b('\n\x0c\x63onfig.proto\x12\x06\x63onfig\x1a\terr.proto\x1a\x0csystem.proto\"$\n\x10GetSystemRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x11GetSystemResponse\x12$\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x14.system.SystemConfig\"J\n\x10SetSystemRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.system.SystemConfig\"\x13\n\x11SetSystemResponse\"P\n\x15SetSystemMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.system.SystemConfig\"B\n\x16SetSystemMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse2\xdd\x01\n\x06\x43onfig\x12@\n\tGetSystem\x12\x18.config.GetSystemRequest\x1a\x19.config.GetSystemResponse\x12@\n\tSetSystem\x12\x18.config.SetSystemRequest\x1a\x19.config.SetSystemResponse\x12O\n\x0eSetSystemMulti\x12\x1d.config.SetSystemMultiRequest\x1a\x1e.config.SetSystemMultiResponseB5\n\x19\x63om.supremainc.sdk.configP\x01Z\x16\x62iostar/service/configb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,system__pb2.DESCRIPTOR,])




_GETSYSTEMREQUEST = _descriptor.Descriptor(
  name='GetSystemRequest',
  full_name='config.GetSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='config.GetSystemRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=85,
)


_GETSYSTEMRESPONSE = _descriptor.Descriptor(
  name='GetSystemResponse',
  full_name='config.GetSystemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='config.GetSystemResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=144,
)


_SETSYSTEMREQUEST = _descriptor.Descriptor(
  name='SetSystemRequest',
  full_name='config.SetSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='config.SetSystemRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='config.SetSystemRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=220,
)


_SETSYSTEMRESPONSE = _descriptor.Descriptor(
  name='SetSystemResponse',
  full_name='config.SetSystemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=241,
)


_SETSYSTEMMULTIREQUEST = _descriptor.Descriptor(
  name='SetSystemMultiRequest',
  full_name='config.SetSystemMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='config.SetSystemMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='config.SetSystemMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=323,
)


_SETSYSTEMMULTIRESPONSE = _descriptor.Descriptor(
  name='SetSystemMultiResponse',
  full_name='config.SetSystemMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='config.SetSystemMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=391,
)

_GETSYSTEMRESPONSE.fields_by_name['config'].message_type = system__pb2._SYSTEMCONFIG
_SETSYSTEMREQUEST.fields_by_name['config'].message_type = system__pb2._SYSTEMCONFIG
_SETSYSTEMMULTIREQUEST.fields_by_name['config'].message_type = system__pb2._SYSTEMCONFIG
_SETSYSTEMMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['GetSystemRequest'] = _GETSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['GetSystemResponse'] = _GETSYSTEMRESPONSE
DESCRIPTOR.message_types_by_name['SetSystemRequest'] = _SETSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['SetSystemResponse'] = _SETSYSTEMRESPONSE
DESCRIPTOR.message_types_by_name['SetSystemMultiRequest'] = _SETSYSTEMMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetSystemMultiResponse'] = _SETSYSTEMMULTIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSystemRequest = _reflection.GeneratedProtocolMessageType('GetSystemRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSYSTEMREQUEST,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.GetSystemRequest)
  ))
_sym_db.RegisterMessage(GetSystemRequest)

GetSystemResponse = _reflection.GeneratedProtocolMessageType('GetSystemResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSYSTEMRESPONSE,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.GetSystemResponse)
  ))
_sym_db.RegisterMessage(GetSystemResponse)

SetSystemRequest = _reflection.GeneratedProtocolMessageType('SetSystemRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMREQUEST,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemRequest)
  ))
_sym_db.RegisterMessage(SetSystemRequest)

SetSystemResponse = _reflection.GeneratedProtocolMessageType('SetSystemResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMRESPONSE,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemResponse)
  ))
_sym_db.RegisterMessage(SetSystemResponse)

SetSystemMultiRequest = _reflection.GeneratedProtocolMessageType('SetSystemMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMMULTIREQUEST,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemMultiRequest)
  ))
_sym_db.RegisterMessage(SetSystemMultiRequest)

SetSystemMultiResponse = _reflection.GeneratedProtocolMessageType('SetSystemMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMMULTIRESPONSE,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemMultiResponse)
  ))
_sym_db.RegisterMessage(SetSystemMultiResponse)


DESCRIPTOR._options = None

_CONFIG = _descriptor.ServiceDescriptor(
  name='Config',
  full_name='config.Config',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=394,
  serialized_end=615,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSystem',
    full_name='config.Config.GetSystem',
    index=0,
    containing_service=None,
    input_type=_GETSYSTEMREQUEST,
    output_type=_GETSYSTEMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSystem',
    full_name='config.Config.SetSystem',
    index=1,
    containing_service=None,
    input_type=_SETSYSTEMREQUEST,
    output_type=_SETSYSTEMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSystemMulti',
    full_name='config.Config.SetSystemMulti',
    index=2,
    containing_service=None,
    input_type=_SETSYSTEMMULTIREQUEST,
    output_type=_SETSYSTEMMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIG)

DESCRIPTOR.services_by_name['Config'] = _CONFIG

# @@protoc_insertion_point(module_scope)
