# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: input.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='input.proto',
  package='input',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.inputP\001Z\025biostar/service/input'),
  serialized_pb=_b('\n\x0binput.proto\x12\x05input\x1a\terr.proto\":\n\x14SupervisedInputRange\x12\x10\n\x08MinValue\x18\x01 \x01(\r\x12\x10\n\x08MaxValue\x18\x02 \x01(\r\"\xc1\x01\n\x15SupervisedInputConfig\x12*\n\x05short\x18\x01 \x01(\x0b\x32\x1b.input.SupervisedInputRange\x12)\n\x04open\x18\x02 \x01(\x0b\x32\x1b.input.SupervisedInputRange\x12\'\n\x02on\x18\x03 \x01(\x0b\x32\x1b.input.SupervisedInputRange\x12(\n\x03off\x18\x04 \x01(\x0b\x32\x1b.input.SupervisedInputRange\"\x88\x01\n\x0fSupervisedInput\x12\x11\n\tportIndex\x18\x01 \x01(\r\x12\x34\n\nregistance\x18\x03 \x01(\x0e\x32 .input.SupervisedRegistanceValue\x12,\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x1c.input.SupervisedInputConfig\"q\n\x0bInputConfig\x12\x12\n\nnumOfInput\x18\x01 \x01(\r\x12\x1c\n\x14numOfSupervisedInput\x18\x02 \x01(\r\x12\x30\n\x10supervisedInputs\x18\x03 \x03(\x0b\x32\x16.input.SupervisedInput\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"7\n\x11GetConfigResponse\x12\"\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x12.input.InputConfig\"H\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.input.InputConfig\"\x13\n\x11SetConfigResponse\"N\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.input.InputConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\x98\x01\n\x19SupervisedRegistanceValue\x12\x15\n\x11SUPERVISED_REG_1K\x10\x00\x12\x17\n\x13SUPERVISED_REG_2_2K\x10\x01\x12\x17\n\x13SUPERVISED_REG_4_7K\x10\x02\x12\x16\n\x12SUPERVISED_REG_10K\x10\x03\x12\x1a\n\x15SUPERVISED_REG_CUSTOM\x10\xff\x01\x32\xd6\x01\n\x05Input\x12>\n\tGetConfig\x12\x17.input.GetConfigRequest\x1a\x18.input.GetConfigResponse\x12>\n\tSetConfig\x12\x17.input.SetConfigRequest\x1a\x18.input.SetConfigResponse\x12M\n\x0eSetConfigMulti\x12\x1c.input.SetConfigMultiRequest\x1a\x1d.input.SetConfigMultiResponseB3\n\x18\x63om.supremainc.sdk.inputP\x01Z\x15\x62iostar/service/inputb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_SUPERVISEDREGISTANCEVALUE = _descriptor.EnumDescriptor(
  name='SupervisedRegistanceValue',
  full_name='input.SupervisedRegistanceValue',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_1K', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_2_2K', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_4_7K', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_10K', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_CUSTOM', index=4, number=255,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=882,
  serialized_end=1034,
)
_sym_db.RegisterEnumDescriptor(_SUPERVISEDREGISTANCEVALUE)

SupervisedRegistanceValue = enum_type_wrapper.EnumTypeWrapper(_SUPERVISEDREGISTANCEVALUE)
SUPERVISED_REG_1K = 0
SUPERVISED_REG_2_2K = 1
SUPERVISED_REG_4_7K = 2
SUPERVISED_REG_10K = 3
SUPERVISED_REG_CUSTOM = 255



_SUPERVISEDINPUTRANGE = _descriptor.Descriptor(
  name='SupervisedInputRange',
  full_name='input.SupervisedInputRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='MinValue', full_name='input.SupervisedInputRange.MinValue', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='MaxValue', full_name='input.SupervisedInputRange.MaxValue', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=91,
)


_SUPERVISEDINPUTCONFIG = _descriptor.Descriptor(
  name='SupervisedInputConfig',
  full_name='input.SupervisedInputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='short', full_name='input.SupervisedInputConfig.short', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='input.SupervisedInputConfig.open', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on', full_name='input.SupervisedInputConfig.on', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='off', full_name='input.SupervisedInputConfig.off', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=287,
)


_SUPERVISEDINPUT = _descriptor.Descriptor(
  name='SupervisedInput',
  full_name='input.SupervisedInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='portIndex', full_name='input.SupervisedInput.portIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registance', full_name='input.SupervisedInput.registance', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='input.SupervisedInput.config', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=426,
)


_INPUTCONFIG = _descriptor.Descriptor(
  name='InputConfig',
  full_name='input.InputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numOfInput', full_name='input.InputConfig.numOfInput', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numOfSupervisedInput', full_name='input.InputConfig.numOfSupervisedInput', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supervisedInputs', full_name='input.InputConfig.supervisedInputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=541,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='input.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='input.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=579,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='input.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='input.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=636,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='input.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='input.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='input.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=710,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='input.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=731,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='input.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='input.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='input.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=811,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='input.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='input.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=813,
  serialized_end=879,
)

_SUPERVISEDINPUTCONFIG.fields_by_name['short'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUTCONFIG.fields_by_name['open'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUTCONFIG.fields_by_name['on'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUTCONFIG.fields_by_name['off'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUT.fields_by_name['registance'].enum_type = _SUPERVISEDREGISTANCEVALUE
_SUPERVISEDINPUT.fields_by_name['config'].message_type = _SUPERVISEDINPUTCONFIG
_INPUTCONFIG.fields_by_name['supervisedInputs'].message_type = _SUPERVISEDINPUT
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _INPUTCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _INPUTCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _INPUTCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['SupervisedInputRange'] = _SUPERVISEDINPUTRANGE
DESCRIPTOR.message_types_by_name['SupervisedInputConfig'] = _SUPERVISEDINPUTCONFIG
DESCRIPTOR.message_types_by_name['SupervisedInput'] = _SUPERVISEDINPUT
DESCRIPTOR.message_types_by_name['InputConfig'] = _INPUTCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['SupervisedRegistanceValue'] = _SUPERVISEDREGISTANCEVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SupervisedInputRange = _reflection.GeneratedProtocolMessageType('SupervisedInputRange', (_message.Message,), dict(
  DESCRIPTOR = _SUPERVISEDINPUTRANGE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SupervisedInputRange)
  ))
_sym_db.RegisterMessage(SupervisedInputRange)

SupervisedInputConfig = _reflection.GeneratedProtocolMessageType('SupervisedInputConfig', (_message.Message,), dict(
  DESCRIPTOR = _SUPERVISEDINPUTCONFIG,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SupervisedInputConfig)
  ))
_sym_db.RegisterMessage(SupervisedInputConfig)

SupervisedInput = _reflection.GeneratedProtocolMessageType('SupervisedInput', (_message.Message,), dict(
  DESCRIPTOR = _SUPERVISEDINPUT,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SupervisedInput)
  ))
_sym_db.RegisterMessage(SupervisedInput)

InputConfig = _reflection.GeneratedProtocolMessageType('InputConfig', (_message.Message,), dict(
  DESCRIPTOR = _INPUTCONFIG,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.InputConfig)
  ))
_sym_db.RegisterMessage(InputConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None

_INPUT = _descriptor.ServiceDescriptor(
  name='Input',
  full_name='input.Input',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1037,
  serialized_end=1251,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='input.Input.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='input.Input.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='input.Input.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INPUT)

DESCRIPTOR.services_by_name['Input'] = _INPUT

# @@protoc_insertion_point(module_scope)
