# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tna.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tna.proto',
  package='tna',
  syntax='proto3',
  serialized_options=_b('\n\026com.supremainc.sdk.tnaP\001Z\023biostar/service/tna'),
  serialized_pb=_b('\n\ttna.proto\x12\x03tna\x1a\terr.proto\"r\n\tTNAConfig\x12\x17\n\x04mode\x18\x01 \x01(\x0e\x32\t.tna.Mode\x12\x15\n\x03key\x18\x02 \x01(\x0e\x32\x08.tna.Key\x12\x12\n\nisRequired\x18\x03 \x01(\x08\x12\x11\n\tschedules\x18\x04 \x03(\r\x12\x0e\n\x06labels\x18\x05 \x03(\t\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"3\n\x11GetConfigResponse\x12\x1e\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0e.tna.TNAConfig\"D\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1e\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0e.tna.TNAConfig\"\x13\n\x11SetConfigResponse\"J\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x1e\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0e.tna.TNAConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"&\n\x07JobCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\r\n\x05label\x18\x02 \x01(\t\"\x87\x01\n\x06TNALog\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65viceID\x18\x03 \x01(\r\x12\x0e\n\x06userID\x18\x04 \x01(\t\x12\x11\n\teventCode\x18\x05 \x01(\r\x12\x0f\n\x07subCode\x18\x06 \x01(\r\x12\x18\n\x06TNAKey\x18\x07 \x01(\x0e\x32\x08.tna.Key\"`\n\x0eTNAEventFilter\x12\x11\n\tstartTime\x18\x01 \x01(\r\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\r\x12\x0f\n\x07userIDs\x18\x03 \x03(\t\x12\x19\n\x07TNAKeys\x18\x04 \x03(\x0e\x32\x08.tna.Key\"\x82\x01\n\nJobCodeLog\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65viceID\x18\x03 \x01(\r\x12\x0e\n\x06userID\x18\x04 \x01(\t\x12\x11\n\teventCode\x18\x05 \x01(\r\x12\x0f\n\x07subCode\x18\x06 \x01(\r\x12\x0f\n\x07jobCode\x18\x07 \x01(\r\"[\n\x12JobCodeEventFilter\x12\x11\n\tstartTime\x18\x01 \x01(\r\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\r\x12\x0f\n\x07userIDs\x18\x03 \x03(\t\x12\x10\n\x08jobCodes\x18\x04 \x03(\r\"t\n\x10GetTNALogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\x12#\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x13.tna.TNAEventFilter\"3\n\x11GetTNALogResponse\x12\x1e\n\tTNAEvents\x18\x01 \x03(\x0b\x32\x0b.tna.TNALog\"S\n\x14GetJobCodeLogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\"?\n\x15GetJobCodeLogResponse\x12&\n\rjobCodeEvents\x18\x01 \x03(\x0b\x32\x0f.tna.JobCodeLog*L\n\x04Mode\x12\n\n\x06UNUSED\x10\x00\x12\x0b\n\x07\x42Y_USER\x10\x01\x12\x0f\n\x0b\x42Y_SCHEDULE\x10\x02\x12\x0f\n\x0bLAST_CHOICE\x10\x03\x12\t\n\x05\x46IXED\x10\x04*\xcd\x01\n\x03Key\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05KEY_1\x10\x01\x12\t\n\x05KEY_2\x10\x02\x12\t\n\x05KEY_3\x10\x03\x12\t\n\x05KEY_4\x10\x04\x12\t\n\x05KEY_5\x10\x05\x12\t\n\x05KEY_6\x10\x06\x12\t\n\x05KEY_7\x10\x07\x12\t\n\x05KEY_8\x10\x08\x12\t\n\x05KEY_9\x10\t\x12\n\n\x06KEY_10\x10\n\x12\n\n\x06KEY_11\x10\x0b\x12\n\n\x06KEY_12\x10\x0c\x12\n\n\x06KEY_13\x10\r\x12\n\n\x06KEY_14\x10\x0e\x12\n\n\x06KEY_15\x10\x0f\x12\n\n\x06KEY_16\x10\x10\x32\xcc\x02\n\x03TNA\x12:\n\tGetConfig\x12\x15.tna.GetConfigRequest\x1a\x16.tna.GetConfigResponse\x12:\n\tSetConfig\x12\x15.tna.SetConfigRequest\x1a\x16.tna.SetConfigResponse\x12I\n\x0eSetConfigMulti\x12\x1a.tna.SetConfigMultiRequest\x1a\x1b.tna.SetConfigMultiResponse\x12:\n\tGetTNALog\x12\x15.tna.GetTNALogRequest\x1a\x16.tna.GetTNALogResponse\x12\x46\n\rGetJobCodeLog\x12\x19.tna.GetJobCodeLogRequest\x1a\x1a.tna.GetJobCodeLogResponseB/\n\x16\x63om.supremainc.sdk.tnaP\x01Z\x13\x62iostar/service/tnab\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='tna.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNUSED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BY_USER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BY_SCHEDULE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAST_CHOICE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1294,
  serialized_end=1370,
)
_sym_db.RegisterEnumDescriptor(_MODE)

Mode = enum_type_wrapper.EnumTypeWrapper(_MODE)
_KEY = _descriptor.EnumDescriptor(
  name='Key',
  full_name='tna.Key',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_2', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_3', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_4', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_5', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_6', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_7', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_8', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_9', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_10', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_11', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_12', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_13', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_14', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_15', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_16', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1373,
  serialized_end=1578,
)
_sym_db.RegisterEnumDescriptor(_KEY)

Key = enum_type_wrapper.EnumTypeWrapper(_KEY)
UNUSED = 0
BY_USER = 1
BY_SCHEDULE = 2
LAST_CHOICE = 3
FIXED = 4
UNSPECIFIED = 0
KEY_1 = 1
KEY_2 = 2
KEY_3 = 3
KEY_4 = 4
KEY_5 = 5
KEY_6 = 6
KEY_7 = 7
KEY_8 = 8
KEY_9 = 9
KEY_10 = 10
KEY_11 = 11
KEY_12 = 12
KEY_13 = 13
KEY_14 = 14
KEY_15 = 15
KEY_16 = 16



_TNACONFIG = _descriptor.Descriptor(
  name='TNAConfig',
  full_name='tna.TNAConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='tna.TNAConfig.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='tna.TNAConfig.key', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isRequired', full_name='tna.TNAConfig.isRequired', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedules', full_name='tna.TNAConfig.schedules', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='tna.TNAConfig.labels', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=143,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='tna.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=181,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='tna.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='tna.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=234,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='tna.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='tna.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=304,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='tna.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=325,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='tna.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='tna.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='tna.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=401,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='tna.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='tna.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=469,
)


_JOBCODE = _descriptor.Descriptor(
  name='JobCode',
  full_name='tna.JobCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='tna.JobCode.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='tna.JobCode.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=509,
)


_TNALOG = _descriptor.Descriptor(
  name='TNALog',
  full_name='tna.TNALog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='tna.TNALog.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tna.TNALog.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.TNALog.deviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='tna.TNALog.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='tna.TNALog.eventCode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCode', full_name='tna.TNALog.subCode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TNAKey', full_name='tna.TNALog.TNAKey', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=647,
)


_TNAEVENTFILTER = _descriptor.Descriptor(
  name='TNAEventFilter',
  full_name='tna.TNAEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='tna.TNAEventFilter.startTime', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='tna.TNAEventFilter.endTime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userIDs', full_name='tna.TNAEventFilter.userIDs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TNAKeys', full_name='tna.TNAEventFilter.TNAKeys', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=745,
)


_JOBCODELOG = _descriptor.Descriptor(
  name='JobCodeLog',
  full_name='tna.JobCodeLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='tna.JobCodeLog.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='tna.JobCodeLog.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.JobCodeLog.deviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='tna.JobCodeLog.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='tna.JobCodeLog.eventCode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCode', full_name='tna.JobCodeLog.subCode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jobCode', full_name='tna.JobCodeLog.jobCode', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=878,
)


_JOBCODEEVENTFILTER = _descriptor.Descriptor(
  name='JobCodeEventFilter',
  full_name='tna.JobCodeEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='tna.JobCodeEventFilter.startTime', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='tna.JobCodeEventFilter.endTime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userIDs', full_name='tna.JobCodeEventFilter.userIDs', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jobCodes', full_name='tna.JobCodeEventFilter.jobCodes', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=971,
)


_GETTNALOGREQUEST = _descriptor.Descriptor(
  name='GetTNALogRequest',
  full_name='tna.GetTNALogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.GetTNALogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='tna.GetTNALogRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='tna.GetTNALogRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='tna.GetTNALogRequest.filter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1089,
)


_GETTNALOGRESPONSE = _descriptor.Descriptor(
  name='GetTNALogResponse',
  full_name='tna.GetTNALogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='TNAEvents', full_name='tna.GetTNALogResponse.TNAEvents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1142,
)


_GETJOBCODELOGREQUEST = _descriptor.Descriptor(
  name='GetJobCodeLogRequest',
  full_name='tna.GetJobCodeLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='tna.GetJobCodeLogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='tna.GetJobCodeLogRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='tna.GetJobCodeLogRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1227,
)


_GETJOBCODELOGRESPONSE = _descriptor.Descriptor(
  name='GetJobCodeLogResponse',
  full_name='tna.GetJobCodeLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobCodeEvents', full_name='tna.GetJobCodeLogResponse.jobCodeEvents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1292,
)

_TNACONFIG.fields_by_name['mode'].enum_type = _MODE
_TNACONFIG.fields_by_name['key'].enum_type = _KEY
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _TNACONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _TNACONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _TNACONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_TNALOG.fields_by_name['TNAKey'].enum_type = _KEY
_TNAEVENTFILTER.fields_by_name['TNAKeys'].enum_type = _KEY
_GETTNALOGREQUEST.fields_by_name['filter'].message_type = _TNAEVENTFILTER
_GETTNALOGRESPONSE.fields_by_name['TNAEvents'].message_type = _TNALOG
_GETJOBCODELOGRESPONSE.fields_by_name['jobCodeEvents'].message_type = _JOBCODELOG
DESCRIPTOR.message_types_by_name['TNAConfig'] = _TNACONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['JobCode'] = _JOBCODE
DESCRIPTOR.message_types_by_name['TNALog'] = _TNALOG
DESCRIPTOR.message_types_by_name['TNAEventFilter'] = _TNAEVENTFILTER
DESCRIPTOR.message_types_by_name['JobCodeLog'] = _JOBCODELOG
DESCRIPTOR.message_types_by_name['JobCodeEventFilter'] = _JOBCODEEVENTFILTER
DESCRIPTOR.message_types_by_name['GetTNALogRequest'] = _GETTNALOGREQUEST
DESCRIPTOR.message_types_by_name['GetTNALogResponse'] = _GETTNALOGRESPONSE
DESCRIPTOR.message_types_by_name['GetJobCodeLogRequest'] = _GETJOBCODELOGREQUEST
DESCRIPTOR.message_types_by_name['GetJobCodeLogResponse'] = _GETJOBCODELOGRESPONSE
DESCRIPTOR.enum_types_by_name['Mode'] = _MODE
DESCRIPTOR.enum_types_by_name['Key'] = _KEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TNAConfig = _reflection.GeneratedProtocolMessageType('TNAConfig', (_message.Message,), dict(
  DESCRIPTOR = _TNACONFIG,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.TNAConfig)
  ))
_sym_db.RegisterMessage(TNAConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

JobCode = _reflection.GeneratedProtocolMessageType('JobCode', (_message.Message,), dict(
  DESCRIPTOR = _JOBCODE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.JobCode)
  ))
_sym_db.RegisterMessage(JobCode)

TNALog = _reflection.GeneratedProtocolMessageType('TNALog', (_message.Message,), dict(
  DESCRIPTOR = _TNALOG,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.TNALog)
  ))
_sym_db.RegisterMessage(TNALog)

TNAEventFilter = _reflection.GeneratedProtocolMessageType('TNAEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _TNAEVENTFILTER,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.TNAEventFilter)
  ))
_sym_db.RegisterMessage(TNAEventFilter)

JobCodeLog = _reflection.GeneratedProtocolMessageType('JobCodeLog', (_message.Message,), dict(
  DESCRIPTOR = _JOBCODELOG,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.JobCodeLog)
  ))
_sym_db.RegisterMessage(JobCodeLog)

JobCodeEventFilter = _reflection.GeneratedProtocolMessageType('JobCodeEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _JOBCODEEVENTFILTER,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.JobCodeEventFilter)
  ))
_sym_db.RegisterMessage(JobCodeEventFilter)

GetTNALogRequest = _reflection.GeneratedProtocolMessageType('GetTNALogRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTNALOGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetTNALogRequest)
  ))
_sym_db.RegisterMessage(GetTNALogRequest)

GetTNALogResponse = _reflection.GeneratedProtocolMessageType('GetTNALogResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTNALOGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetTNALogResponse)
  ))
_sym_db.RegisterMessage(GetTNALogResponse)

GetJobCodeLogRequest = _reflection.GeneratedProtocolMessageType('GetJobCodeLogRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBCODELOGREQUEST,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetJobCodeLogRequest)
  ))
_sym_db.RegisterMessage(GetJobCodeLogRequest)

GetJobCodeLogResponse = _reflection.GeneratedProtocolMessageType('GetJobCodeLogResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETJOBCODELOGRESPONSE,
  __module__ = 'tna_pb2'
  # @@protoc_insertion_point(class_scope:tna.GetJobCodeLogResponse)
  ))
_sym_db.RegisterMessage(GetJobCodeLogResponse)


DESCRIPTOR._options = None

_TNA = _descriptor.ServiceDescriptor(
  name='TNA',
  full_name='tna.TNA',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1581,
  serialized_end=1913,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='tna.TNA.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='tna.TNA.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='tna.TNA.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTNALog',
    full_name='tna.TNA.GetTNALog',
    index=3,
    containing_service=None,
    input_type=_GETTNALOGREQUEST,
    output_type=_GETTNALOGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetJobCodeLog',
    full_name='tna.TNA.GetJobCodeLog',
    index=4,
    containing_service=None,
    input_type=_GETJOBCODELOGREQUEST,
    output_type=_GETJOBCODELOGRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TNA)

DESCRIPTOR.services_by_name['TNA'] = _TNA

# @@protoc_insertion_point(module_scope)
