# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2
from biostarPython.service import tna_pb2 as tna__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='event.proto',
  package='event',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.eventP\001Z\025biostar/service/event'),
  serialized_pb=_b('\n\x0b\x65vent.proto\x12\x05\x65vent\x1a\terr.proto\x1a\ttna.proto\"T\n\x0f\x44\x65tectInputInfo\x12\x12\n\nioDeviceID\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x1f\n\x05value\x18\x03 \x01(\x0e\x32\x10.event.PortValue\"Q\n\rAlarmZoneInfo\x12\x0e\n\x06zoneID\x18\x01 \x01(\r\x12\x0e\n\x06\x64oorID\x18\x02 \x01(\r\x12\x12\n\nioDeviceID\x18\x03 \x01(\r\x12\x0c\n\x04port\x18\x04 \x01(\r\"4\n\x11InterlockZoneInfo\x12\x0e\n\x06zoneID\x18\x01 \x01(\r\x12\x0f\n\x07\x64oorIDs\x18\x02 \x03(\r\"\xfa\x02\n\x08\x45ventLog\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65viceID\x18\x03 \x01(\r\x12\x0e\n\x06userID\x18\x04 \x01(\t\x12\x10\n\x08\x65ntityID\x18\x05 \x01(\r\x12\x11\n\teventCode\x18\x06 \x01(\r\x12\x0f\n\x07subCode\x18\x07 \x01(\r\x12\x18\n\x06TNAKey\x18\x08 \x01(\x0e\x32\x08.tna.Key\x12\x10\n\x08hasImage\x18\t \x01(\x08\x12\x17\n\x0f\x63hangedOnDevice\x18\n \x01(\x08\x12\x13\n\x0btemperature\x18\x0b \x01(\r\x12\x10\n\x08\x63\x61rdData\x18\x0c \x01(\x0c\x12)\n\tinputInfo\x18\r \x01(\x0b\x32\x16.event.DetectInputInfo\x12+\n\ralarmZoneInfo\x18\x0e \x01(\x0b\x32\x14.event.AlarmZoneInfo\x12\x33\n\x11interlockZoneInfo\x18\x0f \x01(\x0b\x32\x18.event.InterlockZoneInfo\"n\n\x0b\x45ventFilter\x12\x0e\n\x06userID\x18\x01 \x01(\t\x12\x11\n\tstartTime\x18\x02 \x01(\r\x12\x0f\n\x07\x65ndTime\x18\x03 \x01(\r\x12\x11\n\teventCode\x18\x04 \x01(\r\x12\x18\n\x06TNAKey\x18\x05 \x01(\x0e\x32\x08.tna.Key\"+\n\x17\x45nableMonitoringRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1a\n\x18\x45nableMonitoringResponse\"1\n\x1c\x45nableMonitoringMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"I\n\x1d\x45nableMonitoringMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\",\n\x18\x44isableMonitoringRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1b\n\x19\x44isableMonitoringResponse\"2\n\x1d\x44isableMonitoringMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"J\n\x1e\x44isableMonitoringMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"W\n\x1bSubscribeRealtimeLogRequest\x12\x11\n\tqueueSize\x18\x01 \x01(\x05\x12\x11\n\tdeviceIDs\x18\x02 \x03(\r\x12\x12\n\neventCodes\x18\x03 \x03(\r\"1\n\x1cSubscribeRealtimeLogResponse\x12\x11\n\tlogChanID\x18\x01 \x01(\t\"L\n\rGetLogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\"1\n\x0eGetLogResponse\x12\x1f\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0f.event.EventLog\"{\n\x17GetLogWithFilterRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\x12#\n\x07\x66ilters\x18\x04 \x03(\x0b\x32\x12.event.EventFilter\";\n\x18GetLogWithFilterResponse\x12\x1f\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0f.event.EventLog\"\x81\x01\n\x08ImageLog\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x10\n\x08\x64\x65viceID\x18\x03 \x01(\r\x12\x0e\n\x06userID\x18\x04 \x01(\t\x12\x11\n\teventCode\x18\x05 \x01(\r\x12\x0f\n\x07subCode\x18\x06 \x01(\r\x12\x10\n\x08JPGImage\x18\x07 \x01(\x0c\"Q\n\x12GetImageLogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x14\n\x0cstartEventID\x18\x02 \x01(\r\x12\x13\n\x0bmaxNumOfLog\x18\x03 \x01(\r\";\n\x13GetImageLogResponse\x12$\n\x0bimageEvents\x18\x01 \x03(\x0b\x32\x0f.event.ImageLog\"4\n\x0bImageFilter\x12\x11\n\teventCode\x18\x01 \x01(\r\x12\x12\n\nscheduleID\x18\x02 \x01(\r\")\n\x15GetImageFilterRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"=\n\x16GetImageFilterResponse\x12#\n\x07\x66ilters\x18\x01 \x03(\x0b\x32\x12.event.ImageFilter\"N\n\x15SetImageFilterRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.event.ImageFilter\"\x18\n\x16SetImageFilterResponse\"T\n\x1aSetImageFilterMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.event.ImageFilter\"G\n\x1bSetImageFilterMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"#\n\x0f\x43learLogRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x12\n\x10\x43learLogResponse\")\n\x14\x43learLogMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"A\n\x15\x43learLogMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*L\n\tPortValue\x12\x08\n\x04OPEN\x10\x00\x12\n\n\x06\x43LOSED\x10\x01\x12\x14\n\x10SUPERVISED_SHORT\x10\x02\x12\x13\n\x0fSUPERVISED_OPEN\x10\x03\x32\xa5\x08\n\x05\x45vent\x12S\n\x10\x45nableMonitoring\x12\x1e.event.EnableMonitoringRequest\x1a\x1f.event.EnableMonitoringResponse\x12\x62\n\x15\x45nableMonitoringMulti\x12#.event.EnableMonitoringMultiRequest\x1a$.event.EnableMonitoringMultiResponse\x12V\n\x11\x44isableMonitoring\x12\x1f.event.DisableMonitoringRequest\x1a .event.DisableMonitoringResponse\x12\x65\n\x16\x44isableMonitoringMulti\x12$.event.DisableMonitoringMultiRequest\x1a%.event.DisableMonitoringMultiResponse\x12M\n\x14SubscribeRealtimeLog\x12\".event.SubscribeRealtimeLogRequest\x1a\x0f.event.EventLog0\x01\x12\x35\n\x06GetLog\x12\x14.event.GetLogRequest\x1a\x15.event.GetLogResponse\x12S\n\x10GetLogWithFilter\x12\x1e.event.GetLogWithFilterRequest\x1a\x1f.event.GetLogWithFilterResponse\x12\x44\n\x0bGetImageLog\x12\x19.event.GetImageLogRequest\x1a\x1a.event.GetImageLogResponse\x12M\n\x0eGetImageFilter\x12\x1c.event.GetImageFilterRequest\x1a\x1d.event.GetImageFilterResponse\x12M\n\x0eSetImageFilter\x12\x1c.event.SetImageFilterRequest\x1a\x1d.event.SetImageFilterResponse\x12\\\n\x13SetImageFilterMulti\x12!.event.SetImageFilterMultiRequest\x1a\".event.SetImageFilterMultiResponse\x12;\n\x08\x43learLog\x12\x16.event.ClearLogRequest\x1a\x17.event.ClearLogResponse\x12J\n\rClearLogMulti\x12\x1b.event.ClearLogMultiRequest\x1a\x1c.event.ClearLogMultiResponseB3\n\x18\x63om.supremainc.sdk.eventP\x01Z\x15\x62iostar/service/eventb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,tna__pb2.DESCRIPTOR,])

_PORTVALUE = _descriptor.EnumDescriptor(
  name='PortValue',
  full_name='event.PortValue',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLOSED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_SHORT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_OPEN', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2485,
  serialized_end=2561,
)
_sym_db.RegisterEnumDescriptor(_PORTVALUE)

PortValue = enum_type_wrapper.EnumTypeWrapper(_PORTVALUE)
OPEN = 0
CLOSED = 1
SUPERVISED_SHORT = 2
SUPERVISED_OPEN = 3



_DETECTINPUTINFO = _descriptor.Descriptor(
  name='DetectInputInfo',
  full_name='event.DetectInputInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ioDeviceID', full_name='event.DetectInputInfo.ioDeviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='event.DetectInputInfo.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='event.DetectInputInfo.value', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=128,
)


_ALARMZONEINFO = _descriptor.Descriptor(
  name='AlarmZoneInfo',
  full_name='event.AlarmZoneInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='zoneID', full_name='event.AlarmZoneInfo.zoneID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doorID', full_name='event.AlarmZoneInfo.doorID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ioDeviceID', full_name='event.AlarmZoneInfo.ioDeviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='event.AlarmZoneInfo.port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=211,
)


_INTERLOCKZONEINFO = _descriptor.Descriptor(
  name='InterlockZoneInfo',
  full_name='event.InterlockZoneInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='zoneID', full_name='event.InterlockZoneInfo.zoneID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doorIDs', full_name='event.InterlockZoneInfo.doorIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=265,
)


_EVENTLOG = _descriptor.Descriptor(
  name='EventLog',
  full_name='event.EventLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='event.EventLog.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='event.EventLog.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.EventLog.deviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='event.EventLog.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entityID', full_name='event.EventLog.entityID', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='event.EventLog.eventCode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCode', full_name='event.EventLog.subCode', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TNAKey', full_name='event.EventLog.TNAKey', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasImage', full_name='event.EventLog.hasImage', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changedOnDevice', full_name='event.EventLog.changedOnDevice', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='event.EventLog.temperature', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardData', full_name='event.EventLog.cardData', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputInfo', full_name='event.EventLog.inputInfo', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarmZoneInfo', full_name='event.EventLog.alarmZoneInfo', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interlockZoneInfo', full_name='event.EventLog.interlockZoneInfo', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=646,
)


_EVENTFILTER = _descriptor.Descriptor(
  name='EventFilter',
  full_name='event.EventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='event.EventFilter.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='event.EventFilter.startTime', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='event.EventFilter.endTime', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='event.EventFilter.eventCode', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TNAKey', full_name='event.EventFilter.TNAKey', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=758,
)


_ENABLEMONITORINGREQUEST = _descriptor.Descriptor(
  name='EnableMonitoringRequest',
  full_name='event.EnableMonitoringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.EnableMonitoringRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=803,
)


_ENABLEMONITORINGRESPONSE = _descriptor.Descriptor(
  name='EnableMonitoringResponse',
  full_name='event.EnableMonitoringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=805,
  serialized_end=831,
)


_ENABLEMONITORINGMULTIREQUEST = _descriptor.Descriptor(
  name='EnableMonitoringMultiRequest',
  full_name='event.EnableMonitoringMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='event.EnableMonitoringMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=882,
)


_ENABLEMONITORINGMULTIRESPONSE = _descriptor.Descriptor(
  name='EnableMonitoringMultiResponse',
  full_name='event.EnableMonitoringMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='event.EnableMonitoringMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=957,
)


_DISABLEMONITORINGREQUEST = _descriptor.Descriptor(
  name='DisableMonitoringRequest',
  full_name='event.DisableMonitoringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.DisableMonitoringRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1003,
)


_DISABLEMONITORINGRESPONSE = _descriptor.Descriptor(
  name='DisableMonitoringResponse',
  full_name='event.DisableMonitoringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1032,
)


_DISABLEMONITORINGMULTIREQUEST = _descriptor.Descriptor(
  name='DisableMonitoringMultiRequest',
  full_name='event.DisableMonitoringMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='event.DisableMonitoringMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1084,
)


_DISABLEMONITORINGMULTIRESPONSE = _descriptor.Descriptor(
  name='DisableMonitoringMultiResponse',
  full_name='event.DisableMonitoringMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='event.DisableMonitoringMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1086,
  serialized_end=1160,
)


_SUBSCRIBEREALTIMELOGREQUEST = _descriptor.Descriptor(
  name='SubscribeRealtimeLogRequest',
  full_name='event.SubscribeRealtimeLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueSize', full_name='event.SubscribeRealtimeLogRequest.queueSize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='event.SubscribeRealtimeLogRequest.deviceIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCodes', full_name='event.SubscribeRealtimeLogRequest.eventCodes', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1249,
)


_SUBSCRIBEREALTIMELOGRESPONSE = _descriptor.Descriptor(
  name='SubscribeRealtimeLogResponse',
  full_name='event.SubscribeRealtimeLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logChanID', full_name='event.SubscribeRealtimeLogResponse.logChanID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1300,
)


_GETLOGREQUEST = _descriptor.Descriptor(
  name='GetLogRequest',
  full_name='event.GetLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.GetLogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='event.GetLogRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='event.GetLogRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1378,
)


_GETLOGRESPONSE = _descriptor.Descriptor(
  name='GetLogResponse',
  full_name='event.GetLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='event.GetLogResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1380,
  serialized_end=1429,
)


_GETLOGWITHFILTERREQUEST = _descriptor.Descriptor(
  name='GetLogWithFilterRequest',
  full_name='event.GetLogWithFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.GetLogWithFilterRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='event.GetLogWithFilterRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='event.GetLogWithFilterRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='event.GetLogWithFilterRequest.filters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1431,
  serialized_end=1554,
)


_GETLOGWITHFILTERRESPONSE = _descriptor.Descriptor(
  name='GetLogWithFilterResponse',
  full_name='event.GetLogWithFilterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='event.GetLogWithFilterResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1556,
  serialized_end=1615,
)


_IMAGELOG = _descriptor.Descriptor(
  name='ImageLog',
  full_name='event.ImageLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='event.ImageLog.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='event.ImageLog.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.ImageLog.deviceID', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='event.ImageLog.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='event.ImageLog.eventCode', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subCode', full_name='event.ImageLog.subCode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='JPGImage', full_name='event.ImageLog.JPGImage', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1618,
  serialized_end=1747,
)


_GETIMAGELOGREQUEST = _descriptor.Descriptor(
  name='GetImageLogRequest',
  full_name='event.GetImageLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.GetImageLogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startEventID', full_name='event.GetImageLogRequest.startEventID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxNumOfLog', full_name='event.GetImageLogRequest.maxNumOfLog', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1749,
  serialized_end=1830,
)


_GETIMAGELOGRESPONSE = _descriptor.Descriptor(
  name='GetImageLogResponse',
  full_name='event.GetImageLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='imageEvents', full_name='event.GetImageLogResponse.imageEvents', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=1891,
)


_IMAGEFILTER = _descriptor.Descriptor(
  name='ImageFilter',
  full_name='event.ImageFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eventCode', full_name='event.ImageFilter.eventCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleID', full_name='event.ImageFilter.scheduleID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1893,
  serialized_end=1945,
)


_GETIMAGEFILTERREQUEST = _descriptor.Descriptor(
  name='GetImageFilterRequest',
  full_name='event.GetImageFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.GetImageFilterRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1947,
  serialized_end=1988,
)


_GETIMAGEFILTERRESPONSE = _descriptor.Descriptor(
  name='GetImageFilterResponse',
  full_name='event.GetImageFilterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filters', full_name='event.GetImageFilterResponse.filters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1990,
  serialized_end=2051,
)


_SETIMAGEFILTERREQUEST = _descriptor.Descriptor(
  name='SetImageFilterRequest',
  full_name='event.SetImageFilterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.SetImageFilterRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='event.SetImageFilterRequest.filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2131,
)


_SETIMAGEFILTERRESPONSE = _descriptor.Descriptor(
  name='SetImageFilterResponse',
  full_name='event.SetImageFilterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2133,
  serialized_end=2157,
)


_SETIMAGEFILTERMULTIREQUEST = _descriptor.Descriptor(
  name='SetImageFilterMultiRequest',
  full_name='event.SetImageFilterMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='event.SetImageFilterMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filters', full_name='event.SetImageFilterMultiRequest.filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2159,
  serialized_end=2243,
)


_SETIMAGEFILTERMULTIRESPONSE = _descriptor.Descriptor(
  name='SetImageFilterMultiResponse',
  full_name='event.SetImageFilterMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='event.SetImageFilterMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2245,
  serialized_end=2316,
)


_CLEARLOGREQUEST = _descriptor.Descriptor(
  name='ClearLogRequest',
  full_name='event.ClearLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='event.ClearLogRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2353,
)


_CLEARLOGRESPONSE = _descriptor.Descriptor(
  name='ClearLogResponse',
  full_name='event.ClearLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2355,
  serialized_end=2373,
)


_CLEARLOGMULTIREQUEST = _descriptor.Descriptor(
  name='ClearLogMultiRequest',
  full_name='event.ClearLogMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='event.ClearLogMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2375,
  serialized_end=2416,
)


_CLEARLOGMULTIRESPONSE = _descriptor.Descriptor(
  name='ClearLogMultiResponse',
  full_name='event.ClearLogMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='event.ClearLogMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2418,
  serialized_end=2483,
)

_DETECTINPUTINFO.fields_by_name['value'].enum_type = _PORTVALUE
_EVENTLOG.fields_by_name['TNAKey'].enum_type = tna__pb2._KEY
_EVENTLOG.fields_by_name['inputInfo'].message_type = _DETECTINPUTINFO
_EVENTLOG.fields_by_name['alarmZoneInfo'].message_type = _ALARMZONEINFO
_EVENTLOG.fields_by_name['interlockZoneInfo'].message_type = _INTERLOCKZONEINFO
_EVENTFILTER.fields_by_name['TNAKey'].enum_type = tna__pb2._KEY
_ENABLEMONITORINGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DISABLEMONITORINGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GETLOGRESPONSE.fields_by_name['events'].message_type = _EVENTLOG
_GETLOGWITHFILTERREQUEST.fields_by_name['filters'].message_type = _EVENTFILTER
_GETLOGWITHFILTERRESPONSE.fields_by_name['events'].message_type = _EVENTLOG
_GETIMAGELOGRESPONSE.fields_by_name['imageEvents'].message_type = _IMAGELOG
_GETIMAGEFILTERRESPONSE.fields_by_name['filters'].message_type = _IMAGEFILTER
_SETIMAGEFILTERREQUEST.fields_by_name['filters'].message_type = _IMAGEFILTER
_SETIMAGEFILTERMULTIREQUEST.fields_by_name['filters'].message_type = _IMAGEFILTER
_SETIMAGEFILTERMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_CLEARLOGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['DetectInputInfo'] = _DETECTINPUTINFO
DESCRIPTOR.message_types_by_name['AlarmZoneInfo'] = _ALARMZONEINFO
DESCRIPTOR.message_types_by_name['InterlockZoneInfo'] = _INTERLOCKZONEINFO
DESCRIPTOR.message_types_by_name['EventLog'] = _EVENTLOG
DESCRIPTOR.message_types_by_name['EventFilter'] = _EVENTFILTER
DESCRIPTOR.message_types_by_name['EnableMonitoringRequest'] = _ENABLEMONITORINGREQUEST
DESCRIPTOR.message_types_by_name['EnableMonitoringResponse'] = _ENABLEMONITORINGRESPONSE
DESCRIPTOR.message_types_by_name['EnableMonitoringMultiRequest'] = _ENABLEMONITORINGMULTIREQUEST
DESCRIPTOR.message_types_by_name['EnableMonitoringMultiResponse'] = _ENABLEMONITORINGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DisableMonitoringRequest'] = _DISABLEMONITORINGREQUEST
DESCRIPTOR.message_types_by_name['DisableMonitoringResponse'] = _DISABLEMONITORINGRESPONSE
DESCRIPTOR.message_types_by_name['DisableMonitoringMultiRequest'] = _DISABLEMONITORINGMULTIREQUEST
DESCRIPTOR.message_types_by_name['DisableMonitoringMultiResponse'] = _DISABLEMONITORINGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeRealtimeLogRequest'] = _SUBSCRIBEREALTIMELOGREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRealtimeLogResponse'] = _SUBSCRIBEREALTIMELOGRESPONSE
DESCRIPTOR.message_types_by_name['GetLogRequest'] = _GETLOGREQUEST
DESCRIPTOR.message_types_by_name['GetLogResponse'] = _GETLOGRESPONSE
DESCRIPTOR.message_types_by_name['GetLogWithFilterRequest'] = _GETLOGWITHFILTERREQUEST
DESCRIPTOR.message_types_by_name['GetLogWithFilterResponse'] = _GETLOGWITHFILTERRESPONSE
DESCRIPTOR.message_types_by_name['ImageLog'] = _IMAGELOG
DESCRIPTOR.message_types_by_name['GetImageLogRequest'] = _GETIMAGELOGREQUEST
DESCRIPTOR.message_types_by_name['GetImageLogResponse'] = _GETIMAGELOGRESPONSE
DESCRIPTOR.message_types_by_name['ImageFilter'] = _IMAGEFILTER
DESCRIPTOR.message_types_by_name['GetImageFilterRequest'] = _GETIMAGEFILTERREQUEST
DESCRIPTOR.message_types_by_name['GetImageFilterResponse'] = _GETIMAGEFILTERRESPONSE
DESCRIPTOR.message_types_by_name['SetImageFilterRequest'] = _SETIMAGEFILTERREQUEST
DESCRIPTOR.message_types_by_name['SetImageFilterResponse'] = _SETIMAGEFILTERRESPONSE
DESCRIPTOR.message_types_by_name['SetImageFilterMultiRequest'] = _SETIMAGEFILTERMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetImageFilterMultiResponse'] = _SETIMAGEFILTERMULTIRESPONSE
DESCRIPTOR.message_types_by_name['ClearLogRequest'] = _CLEARLOGREQUEST
DESCRIPTOR.message_types_by_name['ClearLogResponse'] = _CLEARLOGRESPONSE
DESCRIPTOR.message_types_by_name['ClearLogMultiRequest'] = _CLEARLOGMULTIREQUEST
DESCRIPTOR.message_types_by_name['ClearLogMultiResponse'] = _CLEARLOGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['PortValue'] = _PORTVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DetectInputInfo = _reflection.GeneratedProtocolMessageType('DetectInputInfo', (_message.Message,), dict(
  DESCRIPTOR = _DETECTINPUTINFO,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.DetectInputInfo)
  ))
_sym_db.RegisterMessage(DetectInputInfo)

AlarmZoneInfo = _reflection.GeneratedProtocolMessageType('AlarmZoneInfo', (_message.Message,), dict(
  DESCRIPTOR = _ALARMZONEINFO,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.AlarmZoneInfo)
  ))
_sym_db.RegisterMessage(AlarmZoneInfo)

InterlockZoneInfo = _reflection.GeneratedProtocolMessageType('InterlockZoneInfo', (_message.Message,), dict(
  DESCRIPTOR = _INTERLOCKZONEINFO,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.InterlockZoneInfo)
  ))
_sym_db.RegisterMessage(InterlockZoneInfo)

EventLog = _reflection.GeneratedProtocolMessageType('EventLog', (_message.Message,), dict(
  DESCRIPTOR = _EVENTLOG,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.EventLog)
  ))
_sym_db.RegisterMessage(EventLog)

EventFilter = _reflection.GeneratedProtocolMessageType('EventFilter', (_message.Message,), dict(
  DESCRIPTOR = _EVENTFILTER,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.EventFilter)
  ))
_sym_db.RegisterMessage(EventFilter)

EnableMonitoringRequest = _reflection.GeneratedProtocolMessageType('EnableMonitoringRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENABLEMONITORINGREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.EnableMonitoringRequest)
  ))
_sym_db.RegisterMessage(EnableMonitoringRequest)

EnableMonitoringResponse = _reflection.GeneratedProtocolMessageType('EnableMonitoringResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENABLEMONITORINGRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.EnableMonitoringResponse)
  ))
_sym_db.RegisterMessage(EnableMonitoringResponse)

EnableMonitoringMultiRequest = _reflection.GeneratedProtocolMessageType('EnableMonitoringMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENABLEMONITORINGMULTIREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.EnableMonitoringMultiRequest)
  ))
_sym_db.RegisterMessage(EnableMonitoringMultiRequest)

EnableMonitoringMultiResponse = _reflection.GeneratedProtocolMessageType('EnableMonitoringMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENABLEMONITORINGMULTIRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.EnableMonitoringMultiResponse)
  ))
_sym_db.RegisterMessage(EnableMonitoringMultiResponse)

DisableMonitoringRequest = _reflection.GeneratedProtocolMessageType('DisableMonitoringRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISABLEMONITORINGREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.DisableMonitoringRequest)
  ))
_sym_db.RegisterMessage(DisableMonitoringRequest)

DisableMonitoringResponse = _reflection.GeneratedProtocolMessageType('DisableMonitoringResponse', (_message.Message,), dict(
  DESCRIPTOR = _DISABLEMONITORINGRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.DisableMonitoringResponse)
  ))
_sym_db.RegisterMessage(DisableMonitoringResponse)

DisableMonitoringMultiRequest = _reflection.GeneratedProtocolMessageType('DisableMonitoringMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISABLEMONITORINGMULTIREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.DisableMonitoringMultiRequest)
  ))
_sym_db.RegisterMessage(DisableMonitoringMultiRequest)

DisableMonitoringMultiResponse = _reflection.GeneratedProtocolMessageType('DisableMonitoringMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DISABLEMONITORINGMULTIRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.DisableMonitoringMultiResponse)
  ))
_sym_db.RegisterMessage(DisableMonitoringMultiResponse)

SubscribeRealtimeLogRequest = _reflection.GeneratedProtocolMessageType('SubscribeRealtimeLogRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREALTIMELOGREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.SubscribeRealtimeLogRequest)
  ))
_sym_db.RegisterMessage(SubscribeRealtimeLogRequest)

SubscribeRealtimeLogResponse = _reflection.GeneratedProtocolMessageType('SubscribeRealtimeLogResponse', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREALTIMELOGRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.SubscribeRealtimeLogResponse)
  ))
_sym_db.RegisterMessage(SubscribeRealtimeLogResponse)

GetLogRequest = _reflection.GeneratedProtocolMessageType('GetLogRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLOGREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetLogRequest)
  ))
_sym_db.RegisterMessage(GetLogRequest)

GetLogResponse = _reflection.GeneratedProtocolMessageType('GetLogResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLOGRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetLogResponse)
  ))
_sym_db.RegisterMessage(GetLogResponse)

GetLogWithFilterRequest = _reflection.GeneratedProtocolMessageType('GetLogWithFilterRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLOGWITHFILTERREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetLogWithFilterRequest)
  ))
_sym_db.RegisterMessage(GetLogWithFilterRequest)

GetLogWithFilterResponse = _reflection.GeneratedProtocolMessageType('GetLogWithFilterResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLOGWITHFILTERRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetLogWithFilterResponse)
  ))
_sym_db.RegisterMessage(GetLogWithFilterResponse)

ImageLog = _reflection.GeneratedProtocolMessageType('ImageLog', (_message.Message,), dict(
  DESCRIPTOR = _IMAGELOG,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.ImageLog)
  ))
_sym_db.RegisterMessage(ImageLog)

GetImageLogRequest = _reflection.GeneratedProtocolMessageType('GetImageLogRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGELOGREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetImageLogRequest)
  ))
_sym_db.RegisterMessage(GetImageLogRequest)

GetImageLogResponse = _reflection.GeneratedProtocolMessageType('GetImageLogResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGELOGRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetImageLogResponse)
  ))
_sym_db.RegisterMessage(GetImageLogResponse)

ImageFilter = _reflection.GeneratedProtocolMessageType('ImageFilter', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEFILTER,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.ImageFilter)
  ))
_sym_db.RegisterMessage(ImageFilter)

GetImageFilterRequest = _reflection.GeneratedProtocolMessageType('GetImageFilterRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGEFILTERREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetImageFilterRequest)
  ))
_sym_db.RegisterMessage(GetImageFilterRequest)

GetImageFilterResponse = _reflection.GeneratedProtocolMessageType('GetImageFilterResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGEFILTERRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.GetImageFilterResponse)
  ))
_sym_db.RegisterMessage(GetImageFilterResponse)

SetImageFilterRequest = _reflection.GeneratedProtocolMessageType('SetImageFilterRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETIMAGEFILTERREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.SetImageFilterRequest)
  ))
_sym_db.RegisterMessage(SetImageFilterRequest)

SetImageFilterResponse = _reflection.GeneratedProtocolMessageType('SetImageFilterResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETIMAGEFILTERRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.SetImageFilterResponse)
  ))
_sym_db.RegisterMessage(SetImageFilterResponse)

SetImageFilterMultiRequest = _reflection.GeneratedProtocolMessageType('SetImageFilterMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETIMAGEFILTERMULTIREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.SetImageFilterMultiRequest)
  ))
_sym_db.RegisterMessage(SetImageFilterMultiRequest)

SetImageFilterMultiResponse = _reflection.GeneratedProtocolMessageType('SetImageFilterMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETIMAGEFILTERMULTIRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.SetImageFilterMultiResponse)
  ))
_sym_db.RegisterMessage(SetImageFilterMultiResponse)

ClearLogRequest = _reflection.GeneratedProtocolMessageType('ClearLogRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLEARLOGREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.ClearLogRequest)
  ))
_sym_db.RegisterMessage(ClearLogRequest)

ClearLogResponse = _reflection.GeneratedProtocolMessageType('ClearLogResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLEARLOGRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.ClearLogResponse)
  ))
_sym_db.RegisterMessage(ClearLogResponse)

ClearLogMultiRequest = _reflection.GeneratedProtocolMessageType('ClearLogMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLEARLOGMULTIREQUEST,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.ClearLogMultiRequest)
  ))
_sym_db.RegisterMessage(ClearLogMultiRequest)

ClearLogMultiResponse = _reflection.GeneratedProtocolMessageType('ClearLogMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLEARLOGMULTIRESPONSE,
  __module__ = 'event_pb2'
  # @@protoc_insertion_point(class_scope:event.ClearLogMultiResponse)
  ))
_sym_db.RegisterMessage(ClearLogMultiResponse)


DESCRIPTOR._options = None

_EVENT = _descriptor.ServiceDescriptor(
  name='Event',
  full_name='event.Event',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2564,
  serialized_end=3625,
  methods=[
  _descriptor.MethodDescriptor(
    name='EnableMonitoring',
    full_name='event.Event.EnableMonitoring',
    index=0,
    containing_service=None,
    input_type=_ENABLEMONITORINGREQUEST,
    output_type=_ENABLEMONITORINGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EnableMonitoringMulti',
    full_name='event.Event.EnableMonitoringMulti',
    index=1,
    containing_service=None,
    input_type=_ENABLEMONITORINGMULTIREQUEST,
    output_type=_ENABLEMONITORINGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisableMonitoring',
    full_name='event.Event.DisableMonitoring',
    index=2,
    containing_service=None,
    input_type=_DISABLEMONITORINGREQUEST,
    output_type=_DISABLEMONITORINGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisableMonitoringMulti',
    full_name='event.Event.DisableMonitoringMulti',
    index=3,
    containing_service=None,
    input_type=_DISABLEMONITORINGMULTIREQUEST,
    output_type=_DISABLEMONITORINGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeRealtimeLog',
    full_name='event.Event.SubscribeRealtimeLog',
    index=4,
    containing_service=None,
    input_type=_SUBSCRIBEREALTIMELOGREQUEST,
    output_type=_EVENTLOG,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLog',
    full_name='event.Event.GetLog',
    index=5,
    containing_service=None,
    input_type=_GETLOGREQUEST,
    output_type=_GETLOGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLogWithFilter',
    full_name='event.Event.GetLogWithFilter',
    index=6,
    containing_service=None,
    input_type=_GETLOGWITHFILTERREQUEST,
    output_type=_GETLOGWITHFILTERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageLog',
    full_name='event.Event.GetImageLog',
    index=7,
    containing_service=None,
    input_type=_GETIMAGELOGREQUEST,
    output_type=_GETIMAGELOGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageFilter',
    full_name='event.Event.GetImageFilter',
    index=8,
    containing_service=None,
    input_type=_GETIMAGEFILTERREQUEST,
    output_type=_GETIMAGEFILTERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetImageFilter',
    full_name='event.Event.SetImageFilter',
    index=9,
    containing_service=None,
    input_type=_SETIMAGEFILTERREQUEST,
    output_type=_SETIMAGEFILTERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetImageFilterMulti',
    full_name='event.Event.SetImageFilterMulti',
    index=10,
    containing_service=None,
    input_type=_SETIMAGEFILTERMULTIREQUEST,
    output_type=_SETIMAGEFILTERMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearLog',
    full_name='event.Event.ClearLog',
    index=11,
    containing_service=None,
    input_type=_CLEARLOGREQUEST,
    output_type=_CLEARLOGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ClearLogMulti',
    full_name='event.Event.ClearLogMulti',
    index=12,
    containing_service=None,
    input_type=_CLEARLOGMULTIREQUEST,
    output_type=_CLEARLOGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENT)

DESCRIPTOR.services_by_name['Event'] = _EVENT

# @@protoc_insertion_point(module_scope)
