# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2
from biostarPython.service import connect_pb2 as connect__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='network.proto',
  package='network',
  syntax='proto3',
  serialized_options=_b('\n\032com.supremainc.sdk.networkP\001Z\027biostar/service/network'),
  serialized_pb=_b('\n\rnetwork.proto\x12\x07network\x1a\terr.proto\x1a\rconnect.proto\"&\n\x12GetIPConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"8\n\x13GetIPConfigResponse\x12!\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x11.network.IPConfig\"I\n\x12SetIPConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12!\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x11.network.IPConfig\"\x15\n\x13SetIPConfigResponse\"O\n\x17SetIPConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12!\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x11.network.IPConfig\"D\n\x18SetIPConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xc2\x02\n\x08IPConfig\x12\x0f\n\x07useDHCP\x18\x01 \x01(\x08\x12\x0e\n\x06IPAddr\x18\x02 \x01(\t\x12\x0f\n\x07gateway\x18\x03 \x01(\t\x12\x12\n\nsubnetMask\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12/\n\x0e\x63onnectionMode\x18\x06 \x01(\x0e\x32\x17.connect.ConnectionMode\x12\x12\n\nserverAddr\x18\x07 \x01(\t\x12\x12\n\nserverPort\x18\x08 \x01(\x05\x12\x15\n\rSSLServerPort\x18\t \x01(\x05\x12\x0e\n\x06useDNS\x18\n \x01(\x08\x12\x11\n\tDNSServer\x18\x0b \x01(\t\x12\x11\n\tserverURL\x18\x0c \x01(\t\x12\x0f\n\x07MTUSize\x18\r \x01(\x05\x12+\n\x08\x62\x61seband\x18\x0e \x01(\x0e\x32\x19.network.EthernetBaseband\"(\n\x14GetWLANConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"<\n\x15GetWLANConfigResponse\x12#\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x13.network.WLANConfig\"M\n\x14SetWLANConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12#\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x13.network.WLANConfig\"\x17\n\x15SetWLANConfigResponse\"S\n\x19SetWLANConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12#\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x13.network.WLANConfig\"F\n\x1aSetWLANConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xc0\x01\n\nWLANConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12*\n\x06opMode\x18\x02 \x01(\x0e\x32\x1a.network.WLANOperationMode\x12\'\n\x08\x61uthType\x18\x03 \x01(\x0e\x32\x15.network.WLANAuthType\x12,\n\x07\x65ncType\x18\x04 \x01(\x0e\x32\x1b.network.WLANEncryptionType\x12\r\n\x05\x45SSID\x18\x05 \x01(\t\x12\x0f\n\x07\x61uthKey\x18\x06 \x01(\t*A\n\x10\x45thernetBaseband\x12\x15\n\x11\x42\x41SEBAND_10BASE_T\x10\x00\x12\x16\n\x12\x42\x41SEBAND_100BASE_T\x10\x01*C\n\x11WLANOperationMode\x12\x17\n\x13WLAN_OPMODE_MANAGED\x10\x00\x12\x15\n\x11WLAN_OPMODE_ADHOC\x10\x01*g\n\x0cWLANAuthType\x12\x12\n\x0eWLAN_AUTH_OPEN\x10\x00\x12\x14\n\x10WLAN_AUTH_SHARED\x10\x01\x12\x15\n\x11WLAN_AUTH_WPA_PSK\x10\x02\x12\x16\n\x12WLAN_AUTH_WPA2_PSK\x10\x03*\x85\x01\n\x12WLANEncryptionType\x12\x11\n\rWLAN_ENC_NONE\x10\x00\x12\x14\n\x10\x42S2_WLAN_ENC_WEP\x10\x01\x12\x19\n\x15\x42S2_WLAN_ENC_TKIP_AES\x10\x02\x12\x14\n\x10\x42S2_WLAN_ENC_AES\x10\x03\x12\x15\n\x11\x42S2_WLAN_ENC_TKIP\x10\x04\x32\xf5\x03\n\x07Network\x12H\n\x0bGetIPConfig\x12\x1b.network.GetIPConfigRequest\x1a\x1c.network.GetIPConfigResponse\x12H\n\x0bSetIPConfig\x12\x1b.network.SetIPConfigRequest\x1a\x1c.network.SetIPConfigResponse\x12W\n\x10SetIPConfigMulti\x12 .network.SetIPConfigMultiRequest\x1a!.network.SetIPConfigMultiResponse\x12N\n\rGetWLANConfig\x12\x1d.network.GetWLANConfigRequest\x1a\x1e.network.GetWLANConfigResponse\x12N\n\rSetWLANConfig\x12\x1d.network.SetWLANConfigRequest\x1a\x1e.network.SetWLANConfigResponse\x12]\n\x12SetWLANConfigMulti\x12\".network.SetWLANConfigMultiRequest\x1a#.network.SetWLANConfigMultiResponseB7\n\x1a\x63om.supremainc.sdk.networkP\x01Z\x17\x62iostar/service/networkb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,connect__pb2.DESCRIPTOR,])

_ETHERNETBASEBAND = _descriptor.EnumDescriptor(
  name='EthernetBaseband',
  full_name='network.EthernetBaseband',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASEBAND_10BASE_T', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BASEBAND_100BASE_T', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1284,
  serialized_end=1349,
)
_sym_db.RegisterEnumDescriptor(_ETHERNETBASEBAND)

EthernetBaseband = enum_type_wrapper.EnumTypeWrapper(_ETHERNETBASEBAND)
_WLANOPERATIONMODE = _descriptor.EnumDescriptor(
  name='WLANOperationMode',
  full_name='network.WLANOperationMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WLAN_OPMODE_MANAGED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WLAN_OPMODE_ADHOC', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1351,
  serialized_end=1418,
)
_sym_db.RegisterEnumDescriptor(_WLANOPERATIONMODE)

WLANOperationMode = enum_type_wrapper.EnumTypeWrapper(_WLANOPERATIONMODE)
_WLANAUTHTYPE = _descriptor.EnumDescriptor(
  name='WLANAuthType',
  full_name='network.WLANAuthType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WLAN_AUTH_OPEN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WLAN_AUTH_SHARED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WLAN_AUTH_WPA_PSK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WLAN_AUTH_WPA2_PSK', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1420,
  serialized_end=1523,
)
_sym_db.RegisterEnumDescriptor(_WLANAUTHTYPE)

WLANAuthType = enum_type_wrapper.EnumTypeWrapper(_WLANAUTHTYPE)
_WLANENCRYPTIONTYPE = _descriptor.EnumDescriptor(
  name='WLANEncryptionType',
  full_name='network.WLANEncryptionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WLAN_ENC_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_WLAN_ENC_WEP', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_WLAN_ENC_TKIP_AES', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_WLAN_ENC_AES', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BS2_WLAN_ENC_TKIP', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1526,
  serialized_end=1659,
)
_sym_db.RegisterEnumDescriptor(_WLANENCRYPTIONTYPE)

WLANEncryptionType = enum_type_wrapper.EnumTypeWrapper(_WLANENCRYPTIONTYPE)
BASEBAND_10BASE_T = 0
BASEBAND_100BASE_T = 1
WLAN_OPMODE_MANAGED = 0
WLAN_OPMODE_ADHOC = 1
WLAN_AUTH_OPEN = 0
WLAN_AUTH_SHARED = 1
WLAN_AUTH_WPA_PSK = 2
WLAN_AUTH_WPA2_PSK = 3
WLAN_ENC_NONE = 0
BS2_WLAN_ENC_WEP = 1
BS2_WLAN_ENC_TKIP_AES = 2
BS2_WLAN_ENC_AES = 3
BS2_WLAN_ENC_TKIP = 4



_GETIPCONFIGREQUEST = _descriptor.Descriptor(
  name='GetIPConfigRequest',
  full_name='network.GetIPConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='network.GetIPConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=90,
)


_GETIPCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetIPConfigResponse',
  full_name='network.GetIPConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='network.GetIPConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=148,
)


_SETIPCONFIGREQUEST = _descriptor.Descriptor(
  name='SetIPConfigRequest',
  full_name='network.SetIPConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='network.SetIPConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='network.SetIPConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=223,
)


_SETIPCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetIPConfigResponse',
  full_name='network.SetIPConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=246,
)


_SETIPCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetIPConfigMultiRequest',
  full_name='network.SetIPConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='network.SetIPConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='network.SetIPConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=327,
)


_SETIPCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetIPConfigMultiResponse',
  full_name='network.SetIPConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='network.SetIPConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=397,
)


_IPCONFIG = _descriptor.Descriptor(
  name='IPConfig',
  full_name='network.IPConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='useDHCP', full_name='network.IPConfig.useDHCP', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='IPAddr', full_name='network.IPConfig.IPAddr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gateway', full_name='network.IPConfig.gateway', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subnetMask', full_name='network.IPConfig.subnetMask', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='network.IPConfig.port', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connectionMode', full_name='network.IPConfig.connectionMode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverAddr', full_name='network.IPConfig.serverAddr', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverPort', full_name='network.IPConfig.serverPort', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SSLServerPort', full_name='network.IPConfig.SSLServerPort', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useDNS', full_name='network.IPConfig.useDNS', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DNSServer', full_name='network.IPConfig.DNSServer', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverURL', full_name='network.IPConfig.serverURL', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='MTUSize', full_name='network.IPConfig.MTUSize', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseband', full_name='network.IPConfig.baseband', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=722,
)


_GETWLANCONFIGREQUEST = _descriptor.Descriptor(
  name='GetWLANConfigRequest',
  full_name='network.GetWLANConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='network.GetWLANConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=764,
)


_GETWLANCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetWLANConfigResponse',
  full_name='network.GetWLANConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='network.GetWLANConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=826,
)


_SETWLANCONFIGREQUEST = _descriptor.Descriptor(
  name='SetWLANConfigRequest',
  full_name='network.SetWLANConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='network.SetWLANConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='network.SetWLANConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=828,
  serialized_end=905,
)


_SETWLANCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetWLANConfigResponse',
  full_name='network.SetWLANConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=930,
)


_SETWLANCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetWLANConfigMultiRequest',
  full_name='network.SetWLANConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='network.SetWLANConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='network.SetWLANConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1015,
)


_SETWLANCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetWLANConfigMultiResponse',
  full_name='network.SetWLANConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='network.SetWLANConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1087,
)


_WLANCONFIG = _descriptor.Descriptor(
  name='WLANConfig',
  full_name='network.WLANConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='network.WLANConfig.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opMode', full_name='network.WLANConfig.opMode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authType', full_name='network.WLANConfig.authType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='encType', full_name='network.WLANConfig.encType', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ESSID', full_name='network.WLANConfig.ESSID', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authKey', full_name='network.WLANConfig.authKey', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1282,
)

_GETIPCONFIGRESPONSE.fields_by_name['config'].message_type = _IPCONFIG
_SETIPCONFIGREQUEST.fields_by_name['config'].message_type = _IPCONFIG
_SETIPCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _IPCONFIG
_SETIPCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_IPCONFIG.fields_by_name['connectionMode'].enum_type = connect__pb2._CONNECTIONMODE
_IPCONFIG.fields_by_name['baseband'].enum_type = _ETHERNETBASEBAND
_GETWLANCONFIGRESPONSE.fields_by_name['config'].message_type = _WLANCONFIG
_SETWLANCONFIGREQUEST.fields_by_name['config'].message_type = _WLANCONFIG
_SETWLANCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _WLANCONFIG
_SETWLANCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_WLANCONFIG.fields_by_name['opMode'].enum_type = _WLANOPERATIONMODE
_WLANCONFIG.fields_by_name['authType'].enum_type = _WLANAUTHTYPE
_WLANCONFIG.fields_by_name['encType'].enum_type = _WLANENCRYPTIONTYPE
DESCRIPTOR.message_types_by_name['GetIPConfigRequest'] = _GETIPCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetIPConfigResponse'] = _GETIPCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetIPConfigRequest'] = _SETIPCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetIPConfigResponse'] = _SETIPCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetIPConfigMultiRequest'] = _SETIPCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetIPConfigMultiResponse'] = _SETIPCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['IPConfig'] = _IPCONFIG
DESCRIPTOR.message_types_by_name['GetWLANConfigRequest'] = _GETWLANCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetWLANConfigResponse'] = _GETWLANCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetWLANConfigRequest'] = _SETWLANCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetWLANConfigResponse'] = _SETWLANCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetWLANConfigMultiRequest'] = _SETWLANCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetWLANConfigMultiResponse'] = _SETWLANCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['WLANConfig'] = _WLANCONFIG
DESCRIPTOR.enum_types_by_name['EthernetBaseband'] = _ETHERNETBASEBAND
DESCRIPTOR.enum_types_by_name['WLANOperationMode'] = _WLANOPERATIONMODE
DESCRIPTOR.enum_types_by_name['WLANAuthType'] = _WLANAUTHTYPE
DESCRIPTOR.enum_types_by_name['WLANEncryptionType'] = _WLANENCRYPTIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetIPConfigRequest = _reflection.GeneratedProtocolMessageType('GetIPConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETIPCONFIGREQUEST,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.GetIPConfigRequest)
  ))
_sym_db.RegisterMessage(GetIPConfigRequest)

GetIPConfigResponse = _reflection.GeneratedProtocolMessageType('GetIPConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETIPCONFIGRESPONSE,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.GetIPConfigResponse)
  ))
_sym_db.RegisterMessage(GetIPConfigResponse)

SetIPConfigRequest = _reflection.GeneratedProtocolMessageType('SetIPConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETIPCONFIGREQUEST,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetIPConfigRequest)
  ))
_sym_db.RegisterMessage(SetIPConfigRequest)

SetIPConfigResponse = _reflection.GeneratedProtocolMessageType('SetIPConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETIPCONFIGRESPONSE,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetIPConfigResponse)
  ))
_sym_db.RegisterMessage(SetIPConfigResponse)

SetIPConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetIPConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETIPCONFIGMULTIREQUEST,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetIPConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetIPConfigMultiRequest)

SetIPConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetIPConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETIPCONFIGMULTIRESPONSE,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetIPConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetIPConfigMultiResponse)

IPConfig = _reflection.GeneratedProtocolMessageType('IPConfig', (_message.Message,), dict(
  DESCRIPTOR = _IPCONFIG,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.IPConfig)
  ))
_sym_db.RegisterMessage(IPConfig)

GetWLANConfigRequest = _reflection.GeneratedProtocolMessageType('GetWLANConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETWLANCONFIGREQUEST,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.GetWLANConfigRequest)
  ))
_sym_db.RegisterMessage(GetWLANConfigRequest)

GetWLANConfigResponse = _reflection.GeneratedProtocolMessageType('GetWLANConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETWLANCONFIGRESPONSE,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.GetWLANConfigResponse)
  ))
_sym_db.RegisterMessage(GetWLANConfigResponse)

SetWLANConfigRequest = _reflection.GeneratedProtocolMessageType('SetWLANConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETWLANCONFIGREQUEST,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetWLANConfigRequest)
  ))
_sym_db.RegisterMessage(SetWLANConfigRequest)

SetWLANConfigResponse = _reflection.GeneratedProtocolMessageType('SetWLANConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETWLANCONFIGRESPONSE,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetWLANConfigResponse)
  ))
_sym_db.RegisterMessage(SetWLANConfigResponse)

SetWLANConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetWLANConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETWLANCONFIGMULTIREQUEST,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetWLANConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetWLANConfigMultiRequest)

SetWLANConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetWLANConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETWLANCONFIGMULTIRESPONSE,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.SetWLANConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetWLANConfigMultiResponse)

WLANConfig = _reflection.GeneratedProtocolMessageType('WLANConfig', (_message.Message,), dict(
  DESCRIPTOR = _WLANCONFIG,
  __module__ = 'network_pb2'
  # @@protoc_insertion_point(class_scope:network.WLANConfig)
  ))
_sym_db.RegisterMessage(WLANConfig)


DESCRIPTOR._options = None

_NETWORK = _descriptor.ServiceDescriptor(
  name='Network',
  full_name='network.Network',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1662,
  serialized_end=2163,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetIPConfig',
    full_name='network.Network.GetIPConfig',
    index=0,
    containing_service=None,
    input_type=_GETIPCONFIGREQUEST,
    output_type=_GETIPCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetIPConfig',
    full_name='network.Network.SetIPConfig',
    index=1,
    containing_service=None,
    input_type=_SETIPCONFIGREQUEST,
    output_type=_SETIPCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetIPConfigMulti',
    full_name='network.Network.SetIPConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETIPCONFIGMULTIREQUEST,
    output_type=_SETIPCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetWLANConfig',
    full_name='network.Network.GetWLANConfig',
    index=3,
    containing_service=None,
    input_type=_GETWLANCONFIGREQUEST,
    output_type=_GETWLANCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetWLANConfig',
    full_name='network.Network.SetWLANConfig',
    index=4,
    containing_service=None,
    input_type=_SETWLANCONFIGREQUEST,
    output_type=_SETWLANCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetWLANConfigMulti',
    full_name='network.Network.SetWLANConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETWLANCONFIGMULTIREQUEST,
    output_type=_SETWLANCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_NETWORK)

DESCRIPTOR.services_by_name['Network'] = _NETWORK

# @@protoc_insertion_point(module_scope)
