# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import login_pb2 as login__pb2


class LoginStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Login = channel.unary_unary(
        '/login.Login/Login',
        request_serializer=login__pb2.LoginRequest.SerializeToString,
        response_deserializer=login__pb2.LoginResponse.FromString,
        )
    self.LoginAdmin = channel.unary_unary(
        '/login.Login/LoginAdmin',
        request_serializer=login__pb2.LoginAdminRequest.SerializeToString,
        response_deserializer=login__pb2.LoginAdminResponse.FromString,
        )
    self.Logout = channel.unary_unary(
        '/login.Login/Logout',
        request_serializer=login__pb2.LogoutRequest.SerializeToString,
        response_deserializer=login__pb2.LogoutResponse.FromString,
        )


class LoginServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Login(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LoginAdmin(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Logout(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_LoginServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Login': grpc.unary_unary_rpc_method_handler(
          servicer.Login,
          request_deserializer=login__pb2.LoginRequest.FromString,
          response_serializer=login__pb2.LoginResponse.SerializeToString,
      ),
      'LoginAdmin': grpc.unary_unary_rpc_method_handler(
          servicer.LoginAdmin,
          request_deserializer=login__pb2.LoginAdminRequest.FromString,
          response_serializer=login__pb2.LoginAdminResponse.SerializeToString,
      ),
      'Logout': grpc.unary_unary_rpc_method_handler(
          servicer.Logout,
          request_deserializer=login__pb2.LogoutRequest.FromString,
          response_serializer=login__pb2.LogoutResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'login.Login', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
