# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: err.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='err.proto',
  package='err',
  syntax='proto3',
  serialized_options=_b('\n\026com.supremainc.sdk.errP\001Z\023biostar/service/err'),
  serialized_pb=_b('\n\terr.proto\x12\x03\x65rr\"<\n\rErrorResponse\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\">\n\x12MultiErrorResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"D\n\x14GatewayErrorResponse\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t2\x07\n\x05\x45rrorB/\n\x16\x63om.supremainc.sdk.errP\x01Z\x13\x62iostar/service/errb\x06proto3')
)




_ERRORRESPONSE = _descriptor.Descriptor(
  name='ErrorResponse',
  full_name='err.ErrorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='err.ErrorResponse.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='err.ErrorResponse.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='err.ErrorResponse.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=78,
)


_MULTIERRORRESPONSE = _descriptor.Descriptor(
  name='MultiErrorResponse',
  full_name='err.MultiErrorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='err.MultiErrorResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=142,
)


_GATEWAYERRORRESPONSE = _descriptor.Descriptor(
  name='GatewayErrorResponse',
  full_name='err.GatewayErrorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='err.GatewayErrorResponse.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='err.GatewayErrorResponse.code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='err.GatewayErrorResponse.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=212,
)

_MULTIERRORRESPONSE.fields_by_name['deviceErrors'].message_type = _ERRORRESPONSE
DESCRIPTOR.message_types_by_name['ErrorResponse'] = _ERRORRESPONSE
DESCRIPTOR.message_types_by_name['MultiErrorResponse'] = _MULTIERRORRESPONSE
DESCRIPTOR.message_types_by_name['GatewayErrorResponse'] = _GATEWAYERRORRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ErrorResponse = _reflection.GeneratedProtocolMessageType('ErrorResponse', (_message.Message,), dict(
  DESCRIPTOR = _ERRORRESPONSE,
  __module__ = 'err_pb2'
  # @@protoc_insertion_point(class_scope:err.ErrorResponse)
  ))
_sym_db.RegisterMessage(ErrorResponse)

MultiErrorResponse = _reflection.GeneratedProtocolMessageType('MultiErrorResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTIERRORRESPONSE,
  __module__ = 'err_pb2'
  # @@protoc_insertion_point(class_scope:err.MultiErrorResponse)
  ))
_sym_db.RegisterMessage(MultiErrorResponse)

GatewayErrorResponse = _reflection.GeneratedProtocolMessageType('GatewayErrorResponse', (_message.Message,), dict(
  DESCRIPTOR = _GATEWAYERRORRESPONSE,
  __module__ = 'err_pb2'
  # @@protoc_insertion_point(class_scope:err.GatewayErrorResponse)
  ))
_sym_db.RegisterMessage(GatewayErrorResponse)


DESCRIPTOR._options = None

_ERROR = _descriptor.ServiceDescriptor(
  name='Error',
  full_name='err.Error',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=214,
  serialized_end=221,
  methods=[
])
_sym_db.RegisterServiceDescriptor(_ERROR)

DESCRIPTOR.services_by_name['Error'] = _ERROR

# @@protoc_insertion_point(module_scope)
