# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import card_pb2 as card__pb2


class CardStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Scan = channel.unary_unary(
        '/card.Card/Scan',
        request_serializer=card__pb2.ScanRequest.SerializeToString,
        response_deserializer=card__pb2.ScanResponse.FromString,
        )
    self.Erase = channel.unary_unary(
        '/card.Card/Erase',
        request_serializer=card__pb2.EraseRequest.SerializeToString,
        response_deserializer=card__pb2.EraseResponse.FromString,
        )
    self.Write = channel.unary_unary(
        '/card.Card/Write',
        request_serializer=card__pb2.WriteRequest.SerializeToString,
        response_deserializer=card__pb2.WriteResponse.FromString,
        )
    self.GetConfig = channel.unary_unary(
        '/card.Card/GetConfig',
        request_serializer=card__pb2.GetConfigRequest.SerializeToString,
        response_deserializer=card__pb2.GetConfigResponse.FromString,
        )
    self.SetConfig = channel.unary_unary(
        '/card.Card/SetConfig',
        request_serializer=card__pb2.SetConfigRequest.SerializeToString,
        response_deserializer=card__pb2.SetConfigResponse.FromString,
        )
    self.SetConfigMulti = channel.unary_unary(
        '/card.Card/SetConfigMulti',
        request_serializer=card__pb2.SetConfigMultiRequest.SerializeToString,
        response_deserializer=card__pb2.SetConfigMultiResponse.FromString,
        )
    self.GetBlacklist = channel.unary_unary(
        '/card.Card/GetBlacklist',
        request_serializer=card__pb2.GetBlacklistRequest.SerializeToString,
        response_deserializer=card__pb2.GetBlacklistResponse.FromString,
        )
    self.AddBlacklist = channel.unary_unary(
        '/card.Card/AddBlacklist',
        request_serializer=card__pb2.AddBlacklistRequest.SerializeToString,
        response_deserializer=card__pb2.AddBlacklistResponse.FromString,
        )
    self.AddBlacklistMulti = channel.unary_unary(
        '/card.Card/AddBlacklistMulti',
        request_serializer=card__pb2.AddBlacklistMultiRequest.SerializeToString,
        response_deserializer=card__pb2.AddBlacklistMultiResponse.FromString,
        )
    self.DeleteBlacklist = channel.unary_unary(
        '/card.Card/DeleteBlacklist',
        request_serializer=card__pb2.DeleteBlacklistRequest.SerializeToString,
        response_deserializer=card__pb2.DeleteBlacklistResponse.FromString,
        )
    self.DeleteBlacklistMulti = channel.unary_unary(
        '/card.Card/DeleteBlacklistMulti',
        request_serializer=card__pb2.DeleteBlacklistMultiRequest.SerializeToString,
        response_deserializer=card__pb2.DeleteBlacklistMultiResponse.FromString,
        )
    self.DeleteAllBlacklist = channel.unary_unary(
        '/card.Card/DeleteAllBlacklist',
        request_serializer=card__pb2.DeleteAllBlacklistRequest.SerializeToString,
        response_deserializer=card__pb2.DeleteAllBlacklistResponse.FromString,
        )
    self.DeleteAllBlacklistMulti = channel.unary_unary(
        '/card.Card/DeleteAllBlacklistMulti',
        request_serializer=card__pb2.DeleteAllBlacklistMultiRequest.SerializeToString,
        response_deserializer=card__pb2.DeleteAllBlacklistMultiResponse.FromString,
        )
    self.Get1XConfig = channel.unary_unary(
        '/card.Card/Get1XConfig',
        request_serializer=card__pb2.Get1XConfigRequest.SerializeToString,
        response_deserializer=card__pb2.Get1XConfigResponse.FromString,
        )
    self.Set1XConfig = channel.unary_unary(
        '/card.Card/Set1XConfig',
        request_serializer=card__pb2.Set1XConfigRequest.SerializeToString,
        response_deserializer=card__pb2.Set1XConfigResponse.FromString,
        )
    self.Set1XConfigMulti = channel.unary_unary(
        '/card.Card/Set1XConfigMulti',
        request_serializer=card__pb2.Set1XConfigMultiRequest.SerializeToString,
        response_deserializer=card__pb2.Set1XConfigMultiResponse.FromString,
        )
    self.WriteQRCode = channel.unary_unary(
        '/card.Card/WriteQRCode',
        request_serializer=card__pb2.WriteQRCodeRequest.SerializeToString,
        response_deserializer=card__pb2.WriteQRCodeResponse.FromString,
        )
    self.GetQRConfig = channel.unary_unary(
        '/card.Card/GetQRConfig',
        request_serializer=card__pb2.GetQRConfigRequest.SerializeToString,
        response_deserializer=card__pb2.GetQRConfigResponse.FromString,
        )
    self.SetQRConfig = channel.unary_unary(
        '/card.Card/SetQRConfig',
        request_serializer=card__pb2.SetQRConfigRequest.SerializeToString,
        response_deserializer=card__pb2.SetQRConfigResponse.FromString,
        )
    self.SetQRConfigMulti = channel.unary_unary(
        '/card.Card/SetQRConfigMulti',
        request_serializer=card__pb2.SetQRConfigMultiRequest.SerializeToString,
        response_deserializer=card__pb2.SetQRConfigMultiResponse.FromString,
        )


class CardServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Scan(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Erase(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Write(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddBlacklistMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteBlacklistMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllBlacklist(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllBlacklistMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Get1XConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Set1XConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Set1XConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WriteQRCode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetQRConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetQRConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetQRConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CardServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Scan': grpc.unary_unary_rpc_method_handler(
          servicer.Scan,
          request_deserializer=card__pb2.ScanRequest.FromString,
          response_serializer=card__pb2.ScanResponse.SerializeToString,
      ),
      'Erase': grpc.unary_unary_rpc_method_handler(
          servicer.Erase,
          request_deserializer=card__pb2.EraseRequest.FromString,
          response_serializer=card__pb2.EraseResponse.SerializeToString,
      ),
      'Write': grpc.unary_unary_rpc_method_handler(
          servicer.Write,
          request_deserializer=card__pb2.WriteRequest.FromString,
          response_serializer=card__pb2.WriteResponse.SerializeToString,
      ),
      'GetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfig,
          request_deserializer=card__pb2.GetConfigRequest.FromString,
          response_serializer=card__pb2.GetConfigResponse.SerializeToString,
      ),
      'SetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfig,
          request_deserializer=card__pb2.SetConfigRequest.FromString,
          response_serializer=card__pb2.SetConfigResponse.SerializeToString,
      ),
      'SetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfigMulti,
          request_deserializer=card__pb2.SetConfigMultiRequest.FromString,
          response_serializer=card__pb2.SetConfigMultiResponse.SerializeToString,
      ),
      'GetBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.GetBlacklist,
          request_deserializer=card__pb2.GetBlacklistRequest.FromString,
          response_serializer=card__pb2.GetBlacklistResponse.SerializeToString,
      ),
      'AddBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.AddBlacklist,
          request_deserializer=card__pb2.AddBlacklistRequest.FromString,
          response_serializer=card__pb2.AddBlacklistResponse.SerializeToString,
      ),
      'AddBlacklistMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddBlacklistMulti,
          request_deserializer=card__pb2.AddBlacklistMultiRequest.FromString,
          response_serializer=card__pb2.AddBlacklistMultiResponse.SerializeToString,
      ),
      'DeleteBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteBlacklist,
          request_deserializer=card__pb2.DeleteBlacklistRequest.FromString,
          response_serializer=card__pb2.DeleteBlacklistResponse.SerializeToString,
      ),
      'DeleteBlacklistMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteBlacklistMulti,
          request_deserializer=card__pb2.DeleteBlacklistMultiRequest.FromString,
          response_serializer=card__pb2.DeleteBlacklistMultiResponse.SerializeToString,
      ),
      'DeleteAllBlacklist': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllBlacklist,
          request_deserializer=card__pb2.DeleteAllBlacklistRequest.FromString,
          response_serializer=card__pb2.DeleteAllBlacklistResponse.SerializeToString,
      ),
      'DeleteAllBlacklistMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllBlacklistMulti,
          request_deserializer=card__pb2.DeleteAllBlacklistMultiRequest.FromString,
          response_serializer=card__pb2.DeleteAllBlacklistMultiResponse.SerializeToString,
      ),
      'Get1XConfig': grpc.unary_unary_rpc_method_handler(
          servicer.Get1XConfig,
          request_deserializer=card__pb2.Get1XConfigRequest.FromString,
          response_serializer=card__pb2.Get1XConfigResponse.SerializeToString,
      ),
      'Set1XConfig': grpc.unary_unary_rpc_method_handler(
          servicer.Set1XConfig,
          request_deserializer=card__pb2.Set1XConfigRequest.FromString,
          response_serializer=card__pb2.Set1XConfigResponse.SerializeToString,
      ),
      'Set1XConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.Set1XConfigMulti,
          request_deserializer=card__pb2.Set1XConfigMultiRequest.FromString,
          response_serializer=card__pb2.Set1XConfigMultiResponse.SerializeToString,
      ),
      'WriteQRCode': grpc.unary_unary_rpc_method_handler(
          servicer.WriteQRCode,
          request_deserializer=card__pb2.WriteQRCodeRequest.FromString,
          response_serializer=card__pb2.WriteQRCodeResponse.SerializeToString,
      ),
      'GetQRConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetQRConfig,
          request_deserializer=card__pb2.GetQRConfigRequest.FromString,
          response_serializer=card__pb2.GetQRConfigResponse.SerializeToString,
      ),
      'SetQRConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetQRConfig,
          request_deserializer=card__pb2.SetQRConfigRequest.FromString,
          response_serializer=card__pb2.SetQRConfigResponse.SerializeToString,
      ),
      'SetQRConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetQRConfigMulti,
          request_deserializer=card__pb2.SetQRConfigMultiRequest.FromString,
          response_serializer=card__pb2.SetQRConfigMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'card.Card', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
