# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: time.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='time.proto',
  package='time',
  syntax='proto3',
  serialized_options=_b('\n\027com.supremainc.sdk.timeP\001Z\024biostar/service/time'),
  serialized_pb=_b('\n\ntime.proto\x12\x04time\x1a\terr.proto\"\x1e\n\nGetRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1e\n\x0bGetResponse\x12\x0f\n\x07GMTTime\x18\x01 \x01(\x04\"/\n\nSetRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x0f\n\x07GMTTime\x18\x02 \x01(\x04\"\r\n\x0bSetResponse\"5\n\x0fSetMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x0f\n\x07GMTTime\x18\x02 \x01(\x04\"<\n\x10SetMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"6\n\nTimeConfig\x12\x10\n\x08timeZone\x18\x01 \x01(\x05\x12\x16\n\x0esyncWithServer\x18\x02 \x01(\x08\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"5\n\x11GetConfigResponse\x12 \n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x10.time.TimeConfig\"F\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.time.TimeConfig\"\x13\n\x11SetConfigResponse\"L\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12 \n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x10.time.TimeConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xa2\x01\n\x08WeekTime\x12\x0c\n\x04year\x18\x01 \x01(\r\x12\x1a\n\x05month\x18\x02 \x01(\x0e\x32\x0b.time.Month\x12\x1e\n\x07ordinal\x18\x03 \x01(\x0e\x32\r.time.Ordinal\x12\x1e\n\x07weekday\x18\x04 \x01(\x0e\x32\r.time.Weekday\x12\x0c\n\x04hour\x18\x05 \x01(\r\x12\x0e\n\x06minute\x18\x06 \x01(\r\x12\x0e\n\x06second\x18\x07 \x01(\r\"e\n\x0b\x44STSchedule\x12!\n\tstartTime\x18\x01 \x01(\x0b\x32\x0e.time.WeekTime\x12\x1f\n\x07\x65ndTime\x18\x02 \x01(\x0b\x32\x0e.time.WeekTime\x12\x12\n\ntimeOffset\x18\x03 \x01(\x05\"1\n\tDSTConfig\x12$\n\tschedules\x18\x01 \x03(\x0b\x32\x11.time.DSTSchedule\"\'\n\x13GetDSTConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"7\n\x14GetDSTConfigResponse\x12\x1f\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0f.time.DSTConfig\"H\n\x13SetDSTConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x1f\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0f.time.DSTConfig\"\x16\n\x14SetDSTConfigResponse\"N\n\x18SetDSTConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x1f\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x0f.time.DSTConfig\"E\n\x19SetDSTConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\xe1\x01\n\x05Month\x12\x11\n\rMONTH_JANUARY\x10\x00\x12\x12\n\x0eMONTH_FEBRUARY\x10\x01\x12\x0f\n\x0bMONTH_MARCH\x10\x02\x12\x0f\n\x0bMONTH_APRIL\x10\x03\x12\r\n\tMONTH_MAY\x10\x04\x12\x0e\n\nMONTH_JUNE\x10\x05\x12\x0e\n\nMONTH_JULY\x10\x06\x12\x10\n\x0cMONTH_AUGUST\x10\x07\x12\x13\n\x0fMONTH_SEPTEMBER\x10\x08\x12\x11\n\rMONTH_OCTOBER\x10\t\x12\x12\n\x0eMONTH_NOVEMBER\x10\n\x12\x12\n\x0eMONTH_DECEMBER\x10\x0b*\x9d\x01\n\x07Weekday\x12\x12\n\x0eWEEKDAY_SUNDAY\x10\x00\x12\x12\n\x0eWEEKDAY_MONDAY\x10\x01\x12\x13\n\x0fWEEKDAY_TUESDAY\x10\x02\x12\x15\n\x11WEEKDAY_WEDNESDAY\x10\x03\x12\x14\n\x10WEEKDAY_THURSDAY\x10\x04\x12\x12\n\x0eWEEKDAY_FRIDAY\x10\x05\x12\x14\n\x10WEEKDAY_SATURDAY\x10\x06*\xe7\x01\n\x07Ordinal\x12\x11\n\rORDINAL_FIRST\x10\x00\x12\x12\n\x0eORDINAL_SECOND\x10\x01\x12\x11\n\rORDINAL_THIRD\x10\x02\x12\x12\n\x0eORDINAL_FOURTH\x10\x03\x12\x11\n\rORDINAL_FIFTH\x10\x04\x12\x11\n\rORDINAL_SIXTH\x10\x05\x12\x13\n\x0fORDINAL_SEVENTH\x10\x06\x12\x12\n\x0eORDINAL_EIGHTH\x10\x07\x12\x11\n\rORDINAL_NINTH\x10\x08\x12\x11\n\rORDINAL_TENTH\x10\t\x12\x19\n\x0cORDINAL_LAST\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x32\xc6\x04\n\x04Time\x12*\n\x03Get\x12\x10.time.GetRequest\x1a\x11.time.GetResponse\x12*\n\x03Set\x12\x10.time.SetRequest\x1a\x11.time.SetResponse\x12\x39\n\x08SetMulti\x12\x15.time.SetMultiRequest\x1a\x16.time.SetMultiResponse\x12<\n\tGetConfig\x12\x16.time.GetConfigRequest\x1a\x17.time.GetConfigResponse\x12<\n\tSetConfig\x12\x16.time.SetConfigRequest\x1a\x17.time.SetConfigResponse\x12K\n\x0eSetConfigMulti\x12\x1b.time.SetConfigMultiRequest\x1a\x1c.time.SetConfigMultiResponse\x12\x45\n\x0cGetDSTConfig\x12\x19.time.GetDSTConfigRequest\x1a\x1a.time.GetDSTConfigResponse\x12\x45\n\x0cSetDSTConfig\x12\x19.time.SetDSTConfigRequest\x1a\x1a.time.SetDSTConfigResponse\x12T\n\x11SetDSTConfigMulti\x12\x1e.time.SetDSTConfigMultiRequest\x1a\x1f.time.SetDSTConfigMultiResponseB1\n\x17\x63om.supremainc.sdk.timeP\x01Z\x14\x62iostar/service/timeb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_MONTH = _descriptor.EnumDescriptor(
  name='Month',
  full_name='time.Month',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MONTH_JANUARY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_FEBRUARY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_MARCH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_APRIL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_MAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_JUNE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_JULY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_AUGUST', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_SEPTEMBER', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_OCTOBER', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_NOVEMBER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONTH_DECEMBER', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1331,
  serialized_end=1556,
)
_sym_db.RegisterEnumDescriptor(_MONTH)

Month = enum_type_wrapper.EnumTypeWrapper(_MONTH)
_WEEKDAY = _descriptor.EnumDescriptor(
  name='Weekday',
  full_name='time.Weekday',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_SUNDAY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_MONDAY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_TUESDAY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_WEDNESDAY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_THURSDAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_FRIDAY', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEEKDAY_SATURDAY', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1559,
  serialized_end=1716,
)
_sym_db.RegisterEnumDescriptor(_WEEKDAY)

Weekday = enum_type_wrapper.EnumTypeWrapper(_WEEKDAY)
_ORDINAL = _descriptor.EnumDescriptor(
  name='Ordinal',
  full_name='time.Ordinal',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_FIRST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_SECOND', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_THIRD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_FOURTH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_FIFTH', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_SIXTH', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_SEVENTH', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_EIGHTH', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_NINTH', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_TENTH', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDINAL_LAST', index=10, number=-1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1719,
  serialized_end=1950,
)
_sym_db.RegisterEnumDescriptor(_ORDINAL)

Ordinal = enum_type_wrapper.EnumTypeWrapper(_ORDINAL)
MONTH_JANUARY = 0
MONTH_FEBRUARY = 1
MONTH_MARCH = 2
MONTH_APRIL = 3
MONTH_MAY = 4
MONTH_JUNE = 5
MONTH_JULY = 6
MONTH_AUGUST = 7
MONTH_SEPTEMBER = 8
MONTH_OCTOBER = 9
MONTH_NOVEMBER = 10
MONTH_DECEMBER = 11
WEEKDAY_SUNDAY = 0
WEEKDAY_MONDAY = 1
WEEKDAY_TUESDAY = 2
WEEKDAY_WEDNESDAY = 3
WEEKDAY_THURSDAY = 4
WEEKDAY_FRIDAY = 5
WEEKDAY_SATURDAY = 6
ORDINAL_FIRST = 0
ORDINAL_SECOND = 1
ORDINAL_THIRD = 2
ORDINAL_FOURTH = 3
ORDINAL_FIFTH = 4
ORDINAL_SIXTH = 5
ORDINAL_SEVENTH = 6
ORDINAL_EIGHTH = 7
ORDINAL_NINTH = 8
ORDINAL_TENTH = 9
ORDINAL_LAST = -1



_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='time.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.GetRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=61,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='time.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='GMTTime', full_name='time.GetResponse.GMTTime', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=93,
)


_SETREQUEST = _descriptor.Descriptor(
  name='SetRequest',
  full_name='time.SetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.SetRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='GMTTime', full_name='time.SetRequest.GMTTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=142,
)


_SETRESPONSE = _descriptor.Descriptor(
  name='SetResponse',
  full_name='time.SetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=157,
)


_SETMULTIREQUEST = _descriptor.Descriptor(
  name='SetMultiRequest',
  full_name='time.SetMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='time.SetMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='GMTTime', full_name='time.SetMultiRequest.GMTTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=212,
)


_SETMULTIRESPONSE = _descriptor.Descriptor(
  name='SetMultiResponse',
  full_name='time.SetMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='time.SetMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=274,
)


_TIMECONFIG = _descriptor.Descriptor(
  name='TimeConfig',
  full_name='time.TimeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeZone', full_name='time.TimeConfig.timeZone', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='syncWithServer', full_name='time.TimeConfig.syncWithServer', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=330,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='time.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=368,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='time.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='time.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=423,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='time.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=495,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='time.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=516,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='time.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='time.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=594,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='time.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='time.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=662,
)


_WEEKTIME = _descriptor.Descriptor(
  name='WeekTime',
  full_name='time.WeekTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='year', full_name='time.WeekTime.year', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='month', full_name='time.WeekTime.month', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='time.WeekTime.ordinal', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weekday', full_name='time.WeekTime.weekday', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hour', full_name='time.WeekTime.hour', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minute', full_name='time.WeekTime.minute', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='second', full_name='time.WeekTime.second', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=827,
)


_DSTSCHEDULE = _descriptor.Descriptor(
  name='DSTSchedule',
  full_name='time.DSTSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='time.DSTSchedule.startTime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='time.DSTSchedule.endTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeOffset', full_name='time.DSTSchedule.timeOffset', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=930,
)


_DSTCONFIG = _descriptor.Descriptor(
  name='DSTConfig',
  full_name='time.DSTConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='time.DSTConfig.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=981,
)


_GETDSTCONFIGREQUEST = _descriptor.Descriptor(
  name='GetDSTConfigRequest',
  full_name='time.GetDSTConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.GetDSTConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1022,
)


_GETDSTCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetDSTConfigResponse',
  full_name='time.GetDSTConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='time.GetDSTConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1079,
)


_SETDSTCONFIGREQUEST = _descriptor.Descriptor(
  name='SetDSTConfigRequest',
  full_name='time.SetDSTConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='time.SetDSTConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetDSTConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1153,
)


_SETDSTCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetDSTConfigResponse',
  full_name='time.SetDSTConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1177,
)


_SETDSTCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetDSTConfigMultiRequest',
  full_name='time.SetDSTConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='time.SetDSTConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='time.SetDSTConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1179,
  serialized_end=1257,
)


_SETDSTCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetDSTConfigMultiResponse',
  full_name='time.SetDSTConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='time.SetDSTConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1259,
  serialized_end=1328,
)

_SETMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _TIMECONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _TIMECONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _TIMECONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_WEEKTIME.fields_by_name['month'].enum_type = _MONTH
_WEEKTIME.fields_by_name['ordinal'].enum_type = _ORDINAL
_WEEKTIME.fields_by_name['weekday'].enum_type = _WEEKDAY
_DSTSCHEDULE.fields_by_name['startTime'].message_type = _WEEKTIME
_DSTSCHEDULE.fields_by_name['endTime'].message_type = _WEEKTIME
_DSTCONFIG.fields_by_name['schedules'].message_type = _DSTSCHEDULE
_GETDSTCONFIGRESPONSE.fields_by_name['config'].message_type = _DSTCONFIG
_SETDSTCONFIGREQUEST.fields_by_name['config'].message_type = _DSTCONFIG
_SETDSTCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _DSTCONFIG
_SETDSTCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['SetRequest'] = _SETREQUEST
DESCRIPTOR.message_types_by_name['SetResponse'] = _SETRESPONSE
DESCRIPTOR.message_types_by_name['SetMultiRequest'] = _SETMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetMultiResponse'] = _SETMULTIRESPONSE
DESCRIPTOR.message_types_by_name['TimeConfig'] = _TIMECONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['WeekTime'] = _WEEKTIME
DESCRIPTOR.message_types_by_name['DSTSchedule'] = _DSTSCHEDULE
DESCRIPTOR.message_types_by_name['DSTConfig'] = _DSTCONFIG
DESCRIPTOR.message_types_by_name['GetDSTConfigRequest'] = _GETDSTCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetDSTConfigResponse'] = _GETDSTCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetDSTConfigRequest'] = _SETDSTCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetDSTConfigResponse'] = _SETDSTCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetDSTConfigMultiRequest'] = _SETDSTCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetDSTConfigMultiResponse'] = _SETDSTCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['Month'] = _MONTH
DESCRIPTOR.enum_types_by_name['Weekday'] = _WEEKDAY
DESCRIPTOR.enum_types_by_name['Ordinal'] = _ORDINAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

SetRequest = _reflection.GeneratedProtocolMessageType('SetRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetRequest)
  ))
_sym_db.RegisterMessage(SetRequest)

SetResponse = _reflection.GeneratedProtocolMessageType('SetResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetResponse)
  ))
_sym_db.RegisterMessage(SetResponse)

SetMultiRequest = _reflection.GeneratedProtocolMessageType('SetMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETMULTIREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetMultiRequest)
  ))
_sym_db.RegisterMessage(SetMultiRequest)

SetMultiResponse = _reflection.GeneratedProtocolMessageType('SetMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETMULTIRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetMultiResponse)
  ))
_sym_db.RegisterMessage(SetMultiResponse)

TimeConfig = _reflection.GeneratedProtocolMessageType('TimeConfig', (_message.Message,), dict(
  DESCRIPTOR = _TIMECONFIG,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.TimeConfig)
  ))
_sym_db.RegisterMessage(TimeConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

WeekTime = _reflection.GeneratedProtocolMessageType('WeekTime', (_message.Message,), dict(
  DESCRIPTOR = _WEEKTIME,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.WeekTime)
  ))
_sym_db.RegisterMessage(WeekTime)

DSTSchedule = _reflection.GeneratedProtocolMessageType('DSTSchedule', (_message.Message,), dict(
  DESCRIPTOR = _DSTSCHEDULE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.DSTSchedule)
  ))
_sym_db.RegisterMessage(DSTSchedule)

DSTConfig = _reflection.GeneratedProtocolMessageType('DSTConfig', (_message.Message,), dict(
  DESCRIPTOR = _DSTCONFIG,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.DSTConfig)
  ))
_sym_db.RegisterMessage(DSTConfig)

GetDSTConfigRequest = _reflection.GeneratedProtocolMessageType('GetDSTConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETDSTCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetDSTConfigRequest)
  ))
_sym_db.RegisterMessage(GetDSTConfigRequest)

GetDSTConfigResponse = _reflection.GeneratedProtocolMessageType('GetDSTConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETDSTCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.GetDSTConfigResponse)
  ))
_sym_db.RegisterMessage(GetDSTConfigResponse)

SetDSTConfigRequest = _reflection.GeneratedProtocolMessageType('SetDSTConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigRequest)
  ))
_sym_db.RegisterMessage(SetDSTConfigRequest)

SetDSTConfigResponse = _reflection.GeneratedProtocolMessageType('SetDSTConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigResponse)
  ))
_sym_db.RegisterMessage(SetDSTConfigResponse)

SetDSTConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetDSTConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGMULTIREQUEST,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetDSTConfigMultiRequest)

SetDSTConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetDSTConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETDSTCONFIGMULTIRESPONSE,
  __module__ = 'time_pb2'
  # @@protoc_insertion_point(class_scope:time.SetDSTConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetDSTConfigMultiResponse)


DESCRIPTOR._options = None

_TIME = _descriptor.ServiceDescriptor(
  name='Time',
  full_name='time.Time',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1953,
  serialized_end=2535,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='time.Time.Get',
    index=0,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Set',
    full_name='time.Time.Set',
    index=1,
    containing_service=None,
    input_type=_SETREQUEST,
    output_type=_SETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetMulti',
    full_name='time.Time.SetMulti',
    index=2,
    containing_service=None,
    input_type=_SETMULTIREQUEST,
    output_type=_SETMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='time.Time.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='time.Time.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='time.Time.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDSTConfig',
    full_name='time.Time.GetDSTConfig',
    index=6,
    containing_service=None,
    input_type=_GETDSTCONFIGREQUEST,
    output_type=_GETDSTCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDSTConfig',
    full_name='time.Time.SetDSTConfig',
    index=7,
    containing_service=None,
    input_type=_SETDSTCONFIGREQUEST,
    output_type=_SETDSTCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetDSTConfigMulti',
    full_name='time.Time.SetDSTConfigMulti',
    index=8,
    containing_service=None,
    input_type=_SETDSTCONFIGMULTIREQUEST,
    output_type=_SETDSTCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TIME)

DESCRIPTOR.services_by_name['Time'] = _TIME

# @@protoc_insertion_point(module_scope)
