# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import card_pb2 as card__pb2
from biostarPython.service import finger_pb2 as finger__pb2
from biostarPython.service import user_pb2 as user__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='server.proto',
  package='server',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.serverP\001Z\026biostar/service/server'),
  serialized_pb=_b('\n\x0cserver.proto\x12\x06server\x1a\ncard.proto\x1a\x0c\x66inger.proto\x1a\nuser.proto\"\x90\x02\n\rServerRequest\x12$\n\x07reqType\x18\x01 \x01(\x0e\x32\x13.server.RequestType\x12\x10\n\x08\x64\x65viceID\x18\x02 \x01(\r\x12\r\n\x05seqNO\x18\x03 \x01(\r\x12(\n\tverifyReq\x18\x04 \x01(\x0b\x32\x15.server.VerifyRequest\x12,\n\x0bidentifyReq\x18\x05 \x01(\x0b\x32\x17.server.IdentifyRequest\x12.\n\x0cglobalAPBReq\x18\x06 \x01(\x0b\x32\x18.server.GlobalAPBRequest\x12\x30\n\ruserPhraseReq\x18\x07 \x01(\x0b\x32\x19.server.UserPhraseRequest\"_\n\rVerifyRequest\x12\x0e\n\x06isCard\x18\x01 \x01(\x08\x12\x1c\n\x08\x63\x61rdType\x18\x02 \x01(\x0e\x32\n.card.Type\x12\x10\n\x08\x63\x61rdData\x18\x03 \x01(\x0c\x12\x0e\n\x06userID\x18\x04 \x01(\t\"W\n\x0fIdentifyRequest\x12.\n\x0etemplateFormat\x18\x01 \x01(\x0e\x32\x16.finger.TemplateFormat\x12\x14\n\x0ctemplateData\x18\x02 \x01(\x0c\"#\n\x10GlobalAPBRequest\x12\x0f\n\x07userIDs\x18\x01 \x03(\t\"#\n\x11UserPhraseRequest\x12\x0e\n\x06userID\x18\x01 \x01(\t\"%\n\x10SubscribeRequest\x12\x11\n\tqueueSize\x18\x01 \x01(\x05\"\x14\n\x12UnsubscribeRequest\"\x15\n\x13UnsubscribeResponse\"~\n\x13HandleVerifyRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x1c\n\x04user\x18\x04 \x01(\x0b\x32\x0e.user.UserInfo\"\x16\n\x14HandleVerifyResponse\"\x80\x01\n\x15HandleIdentifyRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x1c\n\x04user\x18\x04 \x01(\x0b\x32\x0e.user.UserInfo\"\x18\n\x16HandleIdentifyResponse\"s\n\x16HandleGlobalAPBRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x0e\n\x06zoneID\x18\x04 \x01(\r\"\x19\n\x17HandleGlobalAPBResponse\"x\n\x17HandleUserPhraseRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\r\n\x05seqNO\x18\x02 \x01(\r\x12(\n\x07\x65rrCode\x18\x03 \x01(\x0e\x32\x17.server.ServerErrorCode\x12\x12\n\nuserPhrase\x18\x04 \x01(\t\"\x1a\n\x18HandleUserPhraseResponse*x\n\x0bRequestType\x12\x0e\n\nNO_REQUEST\x10\x00\x12\x12\n\x0eVERIFY_REQUEST\x10\x01\x12\x14\n\x10IDENTIFY_REQUEST\x10\x02\x12\x16\n\x12GLOBAL_APB_REQUEST\x10\x03\x12\x17\n\x13USER_PHRASE_REQUEST\x10\x04*\xb5\x01\n\x0fServerErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x18\n\x0bVERIFY_FAIL\x10\xd3\xfd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\rIDENTIFY_FAIL\x10\xd2\xfd\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12HARD_APB_VIOLATION\x10\xce\xf6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12SOFT_APB_VIOLATION\x10\xcd\xf6\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1d\n\x10\x43\x41NNOT_FIND_USER\x10\xb6\xfa\xff\xff\xff\xff\xff\xff\xff\x01\x32\xd7\x03\n\x06Server\x12>\n\tSubscribe\x12\x18.server.SubscribeRequest\x1a\x15.server.ServerRequest0\x01\x12\x46\n\x0bUnsubscribe\x12\x1a.server.UnsubscribeRequest\x1a\x1b.server.UnsubscribeResponse\x12I\n\x0cHandleVerify\x12\x1b.server.HandleVerifyRequest\x1a\x1c.server.HandleVerifyResponse\x12O\n\x0eHandleIdentify\x12\x1d.server.HandleIdentifyRequest\x1a\x1e.server.HandleIdentifyResponse\x12R\n\x0fHandleGlobalAPB\x12\x1e.server.HandleGlobalAPBRequest\x1a\x1f.server.HandleGlobalAPBResponse\x12U\n\x10HandleUserPhrase\x12\x1f.server.HandleUserPhraseRequest\x1a .server.HandleUserPhraseResponseB5\n\x19\x63om.supremainc.sdk.serverP\x01Z\x16\x62iostar/service/serverb\x06proto3')
  ,
  dependencies=[card__pb2.DESCRIPTOR,finger__pb2.DESCRIPTOR,user__pb2.DESCRIPTOR,])

_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='server.RequestType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_REQUEST', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDENTIFY_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GLOBAL_APB_REQUEST', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_PHRASE_REQUEST', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1284,
  serialized_end=1404,
)
_sym_db.RegisterEnumDescriptor(_REQUESTTYPE)

RequestType = enum_type_wrapper.EnumTypeWrapper(_REQUESTTYPE)
_SERVERERRORCODE = _descriptor.EnumDescriptor(
  name='ServerErrorCode',
  full_name='server.ServerErrorCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_FAIL', index=1, number=-301,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDENTIFY_FAIL', index=2, number=-302,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HARD_APB_VIOLATION', index=3, number=-1202,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFT_APB_VIOLATION', index=4, number=-1203,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_FIND_USER', index=5, number=-714,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1407,
  serialized_end=1588,
)
_sym_db.RegisterEnumDescriptor(_SERVERERRORCODE)

ServerErrorCode = enum_type_wrapper.EnumTypeWrapper(_SERVERERRORCODE)
NO_REQUEST = 0
VERIFY_REQUEST = 1
IDENTIFY_REQUEST = 2
GLOBAL_APB_REQUEST = 3
USER_PHRASE_REQUEST = 4
SUCCESS = 0
VERIFY_FAIL = -301
IDENTIFY_FAIL = -302
HARD_APB_VIOLATION = -1202
SOFT_APB_VIOLATION = -1203
CANNOT_FIND_USER = -714



_SERVERREQUEST = _descriptor.Descriptor(
  name='ServerRequest',
  full_name='server.ServerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reqType', full_name='server.ServerRequest.reqType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.ServerRequest.deviceID', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.ServerRequest.seqNO', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifyReq', full_name='server.ServerRequest.verifyReq', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifyReq', full_name='server.ServerRequest.identifyReq', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='globalAPBReq', full_name='server.ServerRequest.globalAPBReq', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userPhraseReq', full_name='server.ServerRequest.userPhraseReq', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=335,
)


_VERIFYREQUEST = _descriptor.Descriptor(
  name='VerifyRequest',
  full_name='server.VerifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isCard', full_name='server.VerifyRequest.isCard', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardType', full_name='server.VerifyRequest.cardType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cardData', full_name='server.VerifyRequest.cardData', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userID', full_name='server.VerifyRequest.userID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=432,
)


_IDENTIFYREQUEST = _descriptor.Descriptor(
  name='IdentifyRequest',
  full_name='server.IdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templateFormat', full_name='server.IdentifyRequest.templateFormat', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateData', full_name='server.IdentifyRequest.templateData', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=521,
)


_GLOBALAPBREQUEST = _descriptor.Descriptor(
  name='GlobalAPBRequest',
  full_name='server.GlobalAPBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userIDs', full_name='server.GlobalAPBRequest.userIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=523,
  serialized_end=558,
)


_USERPHRASEREQUEST = _descriptor.Descriptor(
  name='UserPhraseRequest',
  full_name='server.UserPhraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userID', full_name='server.UserPhraseRequest.userID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=595,
)


_SUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='SubscribeRequest',
  full_name='server.SubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueSize', full_name='server.SubscribeRequest.queueSize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=634,
)


_UNSUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='UnsubscribeRequest',
  full_name='server.UnsubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=656,
)


_UNSUBSCRIBERESPONSE = _descriptor.Descriptor(
  name='UnsubscribeResponse',
  full_name='server.UnsubscribeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=679,
)


_HANDLEVERIFYREQUEST = _descriptor.Descriptor(
  name='HandleVerifyRequest',
  full_name='server.HandleVerifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleVerifyRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleVerifyRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleVerifyRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='server.HandleVerifyRequest.user', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=807,
)


_HANDLEVERIFYRESPONSE = _descriptor.Descriptor(
  name='HandleVerifyResponse',
  full_name='server.HandleVerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=831,
)


_HANDLEIDENTIFYREQUEST = _descriptor.Descriptor(
  name='HandleIdentifyRequest',
  full_name='server.HandleIdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleIdentifyRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleIdentifyRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleIdentifyRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='server.HandleIdentifyRequest.user', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=962,
)


_HANDLEIDENTIFYRESPONSE = _descriptor.Descriptor(
  name='HandleIdentifyResponse',
  full_name='server.HandleIdentifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=988,
)


_HANDLEGLOBALAPBREQUEST = _descriptor.Descriptor(
  name='HandleGlobalAPBRequest',
  full_name='server.HandleGlobalAPBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleGlobalAPBRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleGlobalAPBRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleGlobalAPBRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zoneID', full_name='server.HandleGlobalAPBRequest.zoneID', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1105,
)


_HANDLEGLOBALAPBRESPONSE = _descriptor.Descriptor(
  name='HandleGlobalAPBResponse',
  full_name='server.HandleGlobalAPBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1132,
)


_HANDLEUSERPHRASEREQUEST = _descriptor.Descriptor(
  name='HandleUserPhraseRequest',
  full_name='server.HandleUserPhraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='server.HandleUserPhraseRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqNO', full_name='server.HandleUserPhraseRequest.seqNO', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='server.HandleUserPhraseRequest.errCode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userPhrase', full_name='server.HandleUserPhraseRequest.userPhrase', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1254,
)


_HANDLEUSERPHRASERESPONSE = _descriptor.Descriptor(
  name='HandleUserPhraseResponse',
  full_name='server.HandleUserPhraseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1282,
)

_SERVERREQUEST.fields_by_name['reqType'].enum_type = _REQUESTTYPE
_SERVERREQUEST.fields_by_name['verifyReq'].message_type = _VERIFYREQUEST
_SERVERREQUEST.fields_by_name['identifyReq'].message_type = _IDENTIFYREQUEST
_SERVERREQUEST.fields_by_name['globalAPBReq'].message_type = _GLOBALAPBREQUEST
_SERVERREQUEST.fields_by_name['userPhraseReq'].message_type = _USERPHRASEREQUEST
_VERIFYREQUEST.fields_by_name['cardType'].enum_type = card__pb2._TYPE
_IDENTIFYREQUEST.fields_by_name['templateFormat'].enum_type = finger__pb2._TEMPLATEFORMAT
_HANDLEVERIFYREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
_HANDLEVERIFYREQUEST.fields_by_name['user'].message_type = user__pb2._USERINFO
_HANDLEIDENTIFYREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
_HANDLEIDENTIFYREQUEST.fields_by_name['user'].message_type = user__pb2._USERINFO
_HANDLEGLOBALAPBREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
_HANDLEUSERPHRASEREQUEST.fields_by_name['errCode'].enum_type = _SERVERERRORCODE
DESCRIPTOR.message_types_by_name['ServerRequest'] = _SERVERREQUEST
DESCRIPTOR.message_types_by_name['VerifyRequest'] = _VERIFYREQUEST
DESCRIPTOR.message_types_by_name['IdentifyRequest'] = _IDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['GlobalAPBRequest'] = _GLOBALAPBREQUEST
DESCRIPTOR.message_types_by_name['UserPhraseRequest'] = _USERPHRASEREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRequest'] = _SUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['UnsubscribeRequest'] = _UNSUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['UnsubscribeResponse'] = _UNSUBSCRIBERESPONSE
DESCRIPTOR.message_types_by_name['HandleVerifyRequest'] = _HANDLEVERIFYREQUEST
DESCRIPTOR.message_types_by_name['HandleVerifyResponse'] = _HANDLEVERIFYRESPONSE
DESCRIPTOR.message_types_by_name['HandleIdentifyRequest'] = _HANDLEIDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['HandleIdentifyResponse'] = _HANDLEIDENTIFYRESPONSE
DESCRIPTOR.message_types_by_name['HandleGlobalAPBRequest'] = _HANDLEGLOBALAPBREQUEST
DESCRIPTOR.message_types_by_name['HandleGlobalAPBResponse'] = _HANDLEGLOBALAPBRESPONSE
DESCRIPTOR.message_types_by_name['HandleUserPhraseRequest'] = _HANDLEUSERPHRASEREQUEST
DESCRIPTOR.message_types_by_name['HandleUserPhraseResponse'] = _HANDLEUSERPHRASERESPONSE
DESCRIPTOR.enum_types_by_name['RequestType'] = _REQUESTTYPE
DESCRIPTOR.enum_types_by_name['ServerErrorCode'] = _SERVERERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServerRequest = _reflection.GeneratedProtocolMessageType('ServerRequest', (_message.Message,), dict(
  DESCRIPTOR = _SERVERREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.ServerRequest)
  ))
_sym_db.RegisterMessage(ServerRequest)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.VerifyRequest)
  ))
_sym_db.RegisterMessage(VerifyRequest)

IdentifyRequest = _reflection.GeneratedProtocolMessageType('IdentifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _IDENTIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.IdentifyRequest)
  ))
_sym_db.RegisterMessage(IdentifyRequest)

GlobalAPBRequest = _reflection.GeneratedProtocolMessageType('GlobalAPBRequest', (_message.Message,), dict(
  DESCRIPTOR = _GLOBALAPBREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.GlobalAPBRequest)
  ))
_sym_db.RegisterMessage(GlobalAPBRequest)

UserPhraseRequest = _reflection.GeneratedProtocolMessageType('UserPhraseRequest', (_message.Message,), dict(
  DESCRIPTOR = _USERPHRASEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.UserPhraseRequest)
  ))
_sym_db.RegisterMessage(UserPhraseRequest)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.SubscribeRequest)
  ))
_sym_db.RegisterMessage(SubscribeRequest)

UnsubscribeRequest = _reflection.GeneratedProtocolMessageType('UnsubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _UNSUBSCRIBEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.UnsubscribeRequest)
  ))
_sym_db.RegisterMessage(UnsubscribeRequest)

UnsubscribeResponse = _reflection.GeneratedProtocolMessageType('UnsubscribeResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNSUBSCRIBERESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.UnsubscribeResponse)
  ))
_sym_db.RegisterMessage(UnsubscribeResponse)

HandleVerifyRequest = _reflection.GeneratedProtocolMessageType('HandleVerifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEVERIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleVerifyRequest)
  ))
_sym_db.RegisterMessage(HandleVerifyRequest)

HandleVerifyResponse = _reflection.GeneratedProtocolMessageType('HandleVerifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEVERIFYRESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleVerifyResponse)
  ))
_sym_db.RegisterMessage(HandleVerifyResponse)

HandleIdentifyRequest = _reflection.GeneratedProtocolMessageType('HandleIdentifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEIDENTIFYREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleIdentifyRequest)
  ))
_sym_db.RegisterMessage(HandleIdentifyRequest)

HandleIdentifyResponse = _reflection.GeneratedProtocolMessageType('HandleIdentifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEIDENTIFYRESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleIdentifyResponse)
  ))
_sym_db.RegisterMessage(HandleIdentifyResponse)

HandleGlobalAPBRequest = _reflection.GeneratedProtocolMessageType('HandleGlobalAPBRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEGLOBALAPBREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleGlobalAPBRequest)
  ))
_sym_db.RegisterMessage(HandleGlobalAPBRequest)

HandleGlobalAPBResponse = _reflection.GeneratedProtocolMessageType('HandleGlobalAPBResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEGLOBALAPBRESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleGlobalAPBResponse)
  ))
_sym_db.RegisterMessage(HandleGlobalAPBResponse)

HandleUserPhraseRequest = _reflection.GeneratedProtocolMessageType('HandleUserPhraseRequest', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEUSERPHRASEREQUEST,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleUserPhraseRequest)
  ))
_sym_db.RegisterMessage(HandleUserPhraseRequest)

HandleUserPhraseResponse = _reflection.GeneratedProtocolMessageType('HandleUserPhraseResponse', (_message.Message,), dict(
  DESCRIPTOR = _HANDLEUSERPHRASERESPONSE,
  __module__ = 'server_pb2'
  # @@protoc_insertion_point(class_scope:server.HandleUserPhraseResponse)
  ))
_sym_db.RegisterMessage(HandleUserPhraseResponse)


DESCRIPTOR._options = None

_SERVER = _descriptor.ServiceDescriptor(
  name='Server',
  full_name='server.Server',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1591,
  serialized_end=2062,
  methods=[
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='server.Server.Subscribe',
    index=0,
    containing_service=None,
    input_type=_SUBSCRIBEREQUEST,
    output_type=_SERVERREQUEST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Unsubscribe',
    full_name='server.Server.Unsubscribe',
    index=1,
    containing_service=None,
    input_type=_UNSUBSCRIBEREQUEST,
    output_type=_UNSUBSCRIBERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleVerify',
    full_name='server.Server.HandleVerify',
    index=2,
    containing_service=None,
    input_type=_HANDLEVERIFYREQUEST,
    output_type=_HANDLEVERIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleIdentify',
    full_name='server.Server.HandleIdentify',
    index=3,
    containing_service=None,
    input_type=_HANDLEIDENTIFYREQUEST,
    output_type=_HANDLEIDENTIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleGlobalAPB',
    full_name='server.Server.HandleGlobalAPB',
    index=4,
    containing_service=None,
    input_type=_HANDLEGLOBALAPBREQUEST,
    output_type=_HANDLEGLOBALAPBRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='HandleUserPhrase',
    full_name='server.Server.HandleUserPhrase',
    index=5,
    containing_service=None,
    input_type=_HANDLEUSERPHRASEREQUEST,
    output_type=_HANDLEUSERPHRASERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVER)

DESCRIPTOR.services_by_name['Server'] = _SERVER

# @@protoc_insertion_point(module_scope)
