# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: login.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='login.proto',
  package='login',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.loginP\001Z\025biostar/service/login'),
  serialized_pb=_b('\n\x0blogin.proto\x12\x05login\"\"\n\x0cLoginRequest\x12\x12\n\ntenantCert\x18\x01 \x01(\t\"!\n\rLoginResponse\x12\x10\n\x08jwtToken\x18\x01 \x01(\t\">\n\x11LoginAdminRequest\x12\x17\n\x0f\x61\x64minTenantCert\x18\x01 \x01(\t\x12\x10\n\x08tenantID\x18\x02 \x01(\t\"&\n\x12LoginAdminResponse\x12\x10\n\x08jwtToken\x18\x01 \x01(\t\"\x0f\n\rLogoutRequest\"\x10\n\x0eLogoutResponse2\xb5\x01\n\x05Login\x12\x32\n\x05Login\x12\x13.login.LoginRequest\x1a\x14.login.LoginResponse\x12\x41\n\nLoginAdmin\x12\x18.login.LoginAdminRequest\x1a\x19.login.LoginAdminResponse\x12\x35\n\x06Logout\x12\x14.login.LogoutRequest\x1a\x15.login.LogoutResponseB3\n\x18\x63om.supremainc.sdk.loginP\x01Z\x15\x62iostar/service/loginb\x06proto3')
)




_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='login.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantCert', full_name='login.LoginRequest.tenantCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=56,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='login.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jwtToken', full_name='login.LoginResponse.jwtToken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=91,
)


_LOGINADMINREQUEST = _descriptor.Descriptor(
  name='LoginAdminRequest',
  full_name='login.LoginAdminRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='adminTenantCert', full_name='login.LoginAdminRequest.adminTenantCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='login.LoginAdminRequest.tenantID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=155,
)


_LOGINADMINRESPONSE = _descriptor.Descriptor(
  name='LoginAdminResponse',
  full_name='login.LoginAdminResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jwtToken', full_name='login.LoginAdminResponse.jwtToken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=195,
)


_LOGOUTREQUEST = _descriptor.Descriptor(
  name='LogoutRequest',
  full_name='login.LogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=212,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='login.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=230,
)

DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['LoginAdminRequest'] = _LOGINADMINREQUEST
DESCRIPTOR.message_types_by_name['LoginAdminResponse'] = _LOGINADMINRESPONSE
DESCRIPTOR.message_types_by_name['LogoutRequest'] = _LOGOUTREQUEST
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOGINREQUEST,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginRequest)
  ))
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOGINRESPONSE,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginResponse)
  ))
_sym_db.RegisterMessage(LoginResponse)

LoginAdminRequest = _reflection.GeneratedProtocolMessageType('LoginAdminRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOGINADMINREQUEST,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginAdminRequest)
  ))
_sym_db.RegisterMessage(LoginAdminRequest)

LoginAdminResponse = _reflection.GeneratedProtocolMessageType('LoginAdminResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOGINADMINRESPONSE,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LoginAdminResponse)
  ))
_sym_db.RegisterMessage(LoginAdminResponse)

LogoutRequest = _reflection.GeneratedProtocolMessageType('LogoutRequest', (_message.Message,), dict(
  DESCRIPTOR = _LOGOUTREQUEST,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LogoutRequest)
  ))
_sym_db.RegisterMessage(LogoutRequest)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOGOUTRESPONSE,
  __module__ = 'login_pb2'
  # @@protoc_insertion_point(class_scope:login.LogoutResponse)
  ))
_sym_db.RegisterMessage(LogoutResponse)


DESCRIPTOR._options = None

_LOGIN = _descriptor.ServiceDescriptor(
  name='Login',
  full_name='login.Login',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=233,
  serialized_end=414,
  methods=[
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='login.Login.Login',
    index=0,
    containing_service=None,
    input_type=_LOGINREQUEST,
    output_type=_LOGINRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoginAdmin',
    full_name='login.Login.LoginAdmin',
    index=1,
    containing_service=None,
    input_type=_LOGINADMINREQUEST,
    output_type=_LOGINADMINRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Logout',
    full_name='login.Login.Logout',
    index=2,
    containing_service=None,
    input_type=_LOGOUTREQUEST,
    output_type=_LOGOUTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGIN)

DESCRIPTOR.services_by_name['Login'] = _LOGIN

# @@protoc_insertion_point(module_scope)
