# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: finger.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='finger.proto',
  package='finger',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.fingerP\001Z\026biostar/service/finger'),
  serialized_pb=_b('\n\x0c\x66inger.proto\x12\x06\x66inger\x1a\terr.proto\"<\n\nFingerData\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x02 \x01(\r\x12\x11\n\ttemplates\x18\x03 \x03(\x0c\"i\n\x0bScanRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12.\n\x0etemplateFormat\x18\x02 \x01(\x0e\x32\x16.finger.TemplateFormat\x12\x18\n\x10qualityThreshold\x18\x03 \x01(\r\":\n\x0cScanResponse\x12\x14\n\x0ctemplateData\x18\x01 \x01(\x0c\x12\x14\n\x0cqualityScore\x18\x02 \x01(\r\"#\n\x0fGetImageRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"$\n\x10GetImageResponse\x12\x10\n\x08\x42MPImage\x18\x01 \x01(\x0c\"I\n\rVerifyRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\nfingerData\x18\x02 \x01(\x0b\x32\x12.finger.FingerData\"\x10\n\x0eVerifyResponse\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x11GetConfigResponse\x12$\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x14.finger.FingerConfig\"J\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.finger.FingerConfig\"\x13\n\x11SetConfigResponse\"P\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.finger.FingerConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"\xca\x02\n\x0c\x46ingerConfig\x12,\n\rsecurityLevel\x18\x01 \x01(\x0e\x32\x15.finger.SecurityLevel\x12\"\n\x08\x66\x61stMode\x18\x02 \x01(\x0e\x32\x10.finger.FastMode\x12(\n\x0bsensitivity\x18\x03 \x01(\x0e\x32\x13.finger.Sensitivity\x12&\n\nsensorMode\x18\x04 \x01(\x0e\x32\x12.finger.SensorMode\x12.\n\x0etemplateFormat\x18\x05 \x01(\x0e\x32\x16.finger.TemplateFormat\x12\x13\n\x0bscanTimeout\x18\x06 \x01(\x05\x12\x1a\n\x12\x61\x64vancedEnrollment\x18\x07 \x01(\x08\x12\x11\n\tshowImage\x18\x08 \x01(\x08\x12\"\n\x08LFDLevel\x18\t \x01(\x0e\x32\x10.finger.LFDLevel*`\n\x0eTemplateFormat\x12\x1b\n\x17TEMPLATE_FORMAT_SUPREMA\x10\x00\x12\x17\n\x13TEMPLATE_FORMAT_ISO\x10\x01\x12\x18\n\x14TEMPLATE_FORMAT_ANSI\x10\x02*W\n\rSecurityLevel\x12\n\n\x06SECURE\x10\x00\x12\x0f\n\x0bMORE_SECURE\x10\x01\x12\x0f\n\x0bMOST_SECURE\x10\x02\x12\x14\n\x10\x44\x45\x46\x41ULT_SECURITY\x10\x00\x1a\x02\x10\x01*R\n\x08\x46\x61stMode\x12\r\n\tAUTOMATIC\x10\x00\x12\x08\n\x04\x46\x41ST\x10\x01\x12\n\n\x06\x46\x41STER\x10\x02\x12\x0b\n\x07\x46\x41STEST\x10\x03\x12\x10\n\x0c\x44\x45\x46\x41ULT_FAST\x10\x00\x1a\x02\x10\x01*\x85\x02\n\x0bSensitivity\x12\x14\n\x10LOWEST_SENSITIVE\x10\x00\x12\x14\n\x10LEVEL0_SENSITIVE\x10\x00\x12\x14\n\x10LEVEL1_SENSITIVE\x10\x01\x12\x14\n\x10LEVEL2_SENSITIVE\x10\x02\x12\x14\n\x10LEVEL3_SENSITIVE\x10\x03\x12\x14\n\x10LEVEL4_SENSITIVE\x10\x04\x12\x14\n\x10LEVEL5_SENSITIVE\x10\x05\x12\x14\n\x10LEVEL6_SENSITIVE\x10\x06\x12\x14\n\x10LEVEL7_SENSITIVE\x10\x07\x12\x15\n\x11HIGHEST_SENSITIVE\x10\x07\x12\x15\n\x11\x44\x45\x46\x41ULT_SENSITITY\x10\x07\x1a\x02\x10\x01*T\n\nSensorMode\x12\r\n\tALWAYS_ON\x10\x00\x12\x1a\n\x16\x41\x43TIVATED_BY_PROXIMITY\x10\x01\x12\x17\n\x13\x44\x45\x46\x41ULT_SENSOR_MODE\x10\x00\x1a\x02\x10\x01*[\n\x08LFDLevel\x12\x0c\n\x08NOT_USED\x10\x00\x12\n\n\x06STRICT\x10\x01\x12\x0f\n\x0bMORE_STRICT\x10\x02\x12\x0f\n\x0bMOST_STRICT\x10\x03\x12\x0f\n\x0b\x44\x45\x46\x41ULT_LFD\x10\x00\x1a\x02\x10\x01\x32\x88\x03\n\x06\x46inger\x12\x31\n\x04Scan\x12\x13.finger.ScanRequest\x1a\x14.finger.ScanResponse\x12=\n\x08GetImage\x12\x17.finger.GetImageRequest\x1a\x18.finger.GetImageResponse\x12\x37\n\x06Verify\x12\x15.finger.VerifyRequest\x1a\x16.finger.VerifyResponse\x12@\n\tGetConfig\x12\x18.finger.GetConfigRequest\x1a\x19.finger.GetConfigResponse\x12@\n\tSetConfig\x12\x18.finger.SetConfigRequest\x1a\x19.finger.SetConfigResponse\x12O\n\x0eSetConfigMulti\x12\x1d.finger.SetConfigMultiRequest\x1a\x1e.finger.SetConfigMultiResponseB5\n\x19\x63om.supremainc.sdk.fingerP\x01Z\x16\x62iostar/service/fingerb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_TEMPLATEFORMAT = _descriptor.EnumDescriptor(
  name='TemplateFormat',
  full_name='finger.TemplateFormat',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEMPLATE_FORMAT_SUPREMA', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPLATE_FORMAT_ISO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPLATE_FORMAT_ANSI', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1109,
  serialized_end=1205,
)
_sym_db.RegisterEnumDescriptor(_TEMPLATEFORMAT)

TemplateFormat = enum_type_wrapper.EnumTypeWrapper(_TEMPLATEFORMAT)
_SECURITYLEVEL = _descriptor.EnumDescriptor(
  name='SecurityLevel',
  full_name='finger.SecurityLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SECURE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MORE_SECURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOST_SECURE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SECURITY', index=3, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1207,
  serialized_end=1294,
)
_sym_db.RegisterEnumDescriptor(_SECURITYLEVEL)

SecurityLevel = enum_type_wrapper.EnumTypeWrapper(_SECURITYLEVEL)
_FASTMODE = _descriptor.EnumDescriptor(
  name='FastMode',
  full_name='finger.FastMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTOMATIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAST', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FASTER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FASTEST', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_FAST', index=4, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1296,
  serialized_end=1378,
)
_sym_db.RegisterEnumDescriptor(_FASTMODE)

FastMode = enum_type_wrapper.EnumTypeWrapper(_FASTMODE)
_SENSITIVITY = _descriptor.EnumDescriptor(
  name='Sensitivity',
  full_name='finger.Sensitivity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOWEST_SENSITIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL0_SENSITIVE', index=1, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL1_SENSITIVE', index=2, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL2_SENSITIVE', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL3_SENSITIVE', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL4_SENSITIVE', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL5_SENSITIVE', index=6, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL6_SENSITIVE', index=7, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEVEL7_SENSITIVE', index=8, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGHEST_SENSITIVE', index=9, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SENSITITY', index=10, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1381,
  serialized_end=1642,
)
_sym_db.RegisterEnumDescriptor(_SENSITIVITY)

Sensitivity = enum_type_wrapper.EnumTypeWrapper(_SENSITIVITY)
_SENSORMODE = _descriptor.EnumDescriptor(
  name='SensorMode',
  full_name='finger.SensorMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALWAYS_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVATED_BY_PROXIMITY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_SENSOR_MODE', index=2, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1644,
  serialized_end=1728,
)
_sym_db.RegisterEnumDescriptor(_SENSORMODE)

SensorMode = enum_type_wrapper.EnumTypeWrapper(_SENSORMODE)
_LFDLEVEL = _descriptor.EnumDescriptor(
  name='LFDLevel',
  full_name='finger.LFDLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_USED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRICT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MORE_STRICT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOST_STRICT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_LFD', index=4, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=_b('\020\001'),
  serialized_start=1730,
  serialized_end=1821,
)
_sym_db.RegisterEnumDescriptor(_LFDLEVEL)

LFDLevel = enum_type_wrapper.EnumTypeWrapper(_LFDLEVEL)
TEMPLATE_FORMAT_SUPREMA = 0
TEMPLATE_FORMAT_ISO = 1
TEMPLATE_FORMAT_ANSI = 2
SECURE = 0
MORE_SECURE = 1
MOST_SECURE = 2
DEFAULT_SECURITY = 0
AUTOMATIC = 0
FAST = 1
FASTER = 2
FASTEST = 3
DEFAULT_FAST = 0
LOWEST_SENSITIVE = 0
LEVEL0_SENSITIVE = 0
LEVEL1_SENSITIVE = 1
LEVEL2_SENSITIVE = 2
LEVEL3_SENSITIVE = 3
LEVEL4_SENSITIVE = 4
LEVEL5_SENSITIVE = 5
LEVEL6_SENSITIVE = 6
LEVEL7_SENSITIVE = 7
HIGHEST_SENSITIVE = 7
DEFAULT_SENSITITY = 7
ALWAYS_ON = 0
ACTIVATED_BY_PROXIMITY = 1
DEFAULT_SENSOR_MODE = 0
NOT_USED = 0
STRICT = 1
MORE_STRICT = 2
MOST_STRICT = 3
DEFAULT_LFD = 0



_FINGERDATA = _descriptor.Descriptor(
  name='FingerData',
  full_name='finger.FingerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='finger.FingerData.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flag', full_name='finger.FingerData.flag', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templates', full_name='finger.FingerData.templates', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=95,
)


_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='finger.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.ScanRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateFormat', full_name='finger.ScanRequest.templateFormat', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualityThreshold', full_name='finger.ScanRequest.qualityThreshold', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=202,
)


_SCANRESPONSE = _descriptor.Descriptor(
  name='ScanResponse',
  full_name='finger.ScanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='templateData', full_name='finger.ScanResponse.templateData', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='qualityScore', full_name='finger.ScanResponse.qualityScore', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=262,
)


_GETIMAGEREQUEST = _descriptor.Descriptor(
  name='GetImageRequest',
  full_name='finger.GetImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.GetImageRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=299,
)


_GETIMAGERESPONSE = _descriptor.Descriptor(
  name='GetImageResponse',
  full_name='finger.GetImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='BMPImage', full_name='finger.GetImageResponse.BMPImage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=337,
)


_VERIFYREQUEST = _descriptor.Descriptor(
  name='VerifyRequest',
  full_name='finger.VerifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.VerifyRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fingerData', full_name='finger.VerifyRequest.fingerData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=412,
)


_VERIFYRESPONSE = _descriptor.Descriptor(
  name='VerifyResponse',
  full_name='finger.VerifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=430,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='finger.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=468,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='finger.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='finger.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=527,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='finger.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='finger.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='finger.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=603,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='finger.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=624,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='finger.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='finger.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='finger.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=626,
  serialized_end=706,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='finger.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='finger.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=774,
)


_FINGERCONFIG = _descriptor.Descriptor(
  name='FingerConfig',
  full_name='finger.FingerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='securityLevel', full_name='finger.FingerConfig.securityLevel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fastMode', full_name='finger.FingerConfig.fastMode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='finger.FingerConfig.sensitivity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorMode', full_name='finger.FingerConfig.sensorMode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateFormat', full_name='finger.FingerConfig.templateFormat', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scanTimeout', full_name='finger.FingerConfig.scanTimeout', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advancedEnrollment', full_name='finger.FingerConfig.advancedEnrollment', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showImage', full_name='finger.FingerConfig.showImage', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='LFDLevel', full_name='finger.FingerConfig.LFDLevel', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=1107,
)

_SCANREQUEST.fields_by_name['templateFormat'].enum_type = _TEMPLATEFORMAT
_VERIFYREQUEST.fields_by_name['fingerData'].message_type = _FINGERDATA
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _FINGERCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _FINGERCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _FINGERCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_FINGERCONFIG.fields_by_name['securityLevel'].enum_type = _SECURITYLEVEL
_FINGERCONFIG.fields_by_name['fastMode'].enum_type = _FASTMODE
_FINGERCONFIG.fields_by_name['sensitivity'].enum_type = _SENSITIVITY
_FINGERCONFIG.fields_by_name['sensorMode'].enum_type = _SENSORMODE
_FINGERCONFIG.fields_by_name['templateFormat'].enum_type = _TEMPLATEFORMAT
_FINGERCONFIG.fields_by_name['LFDLevel'].enum_type = _LFDLEVEL
DESCRIPTOR.message_types_by_name['FingerData'] = _FINGERDATA
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ScanResponse'] = _SCANRESPONSE
DESCRIPTOR.message_types_by_name['GetImageRequest'] = _GETIMAGEREQUEST
DESCRIPTOR.message_types_by_name['GetImageResponse'] = _GETIMAGERESPONSE
DESCRIPTOR.message_types_by_name['VerifyRequest'] = _VERIFYREQUEST
DESCRIPTOR.message_types_by_name['VerifyResponse'] = _VERIFYRESPONSE
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.message_types_by_name['FingerConfig'] = _FINGERCONFIG
DESCRIPTOR.enum_types_by_name['TemplateFormat'] = _TEMPLATEFORMAT
DESCRIPTOR.enum_types_by_name['SecurityLevel'] = _SECURITYLEVEL
DESCRIPTOR.enum_types_by_name['FastMode'] = _FASTMODE
DESCRIPTOR.enum_types_by_name['Sensitivity'] = _SENSITIVITY
DESCRIPTOR.enum_types_by_name['SensorMode'] = _SENSORMODE
DESCRIPTOR.enum_types_by_name['LFDLevel'] = _LFDLEVEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FingerData = _reflection.GeneratedProtocolMessageType('FingerData', (_message.Message,), dict(
  DESCRIPTOR = _FINGERDATA,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.FingerData)
  ))
_sym_db.RegisterMessage(FingerData)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCANREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.ScanRequest)
  ))
_sym_db.RegisterMessage(ScanRequest)

ScanResponse = _reflection.GeneratedProtocolMessageType('ScanResponse', (_message.Message,), dict(
  DESCRIPTOR = _SCANRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.ScanResponse)
  ))
_sym_db.RegisterMessage(ScanResponse)

GetImageRequest = _reflection.GeneratedProtocolMessageType('GetImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGEREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetImageRequest)
  ))
_sym_db.RegisterMessage(GetImageRequest)

GetImageResponse = _reflection.GeneratedProtocolMessageType('GetImageResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETIMAGERESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetImageResponse)
  ))
_sym_db.RegisterMessage(GetImageResponse)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.VerifyRequest)
  ))
_sym_db.RegisterMessage(VerifyRequest)

VerifyResponse = _reflection.GeneratedProtocolMessageType('VerifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.VerifyResponse)
  ))
_sym_db.RegisterMessage(VerifyResponse)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)

FingerConfig = _reflection.GeneratedProtocolMessageType('FingerConfig', (_message.Message,), dict(
  DESCRIPTOR = _FINGERCONFIG,
  __module__ = 'finger_pb2'
  # @@protoc_insertion_point(class_scope:finger.FingerConfig)
  ))
_sym_db.RegisterMessage(FingerConfig)


DESCRIPTOR._options = None
_SECURITYLEVEL._options = None
_FASTMODE._options = None
_SENSITIVITY._options = None
_SENSORMODE._options = None
_LFDLEVEL._options = None

_FINGER = _descriptor.ServiceDescriptor(
  name='Finger',
  full_name='finger.Finger',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1824,
  serialized_end=2216,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='finger.Finger.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=_SCANRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetImage',
    full_name='finger.Finger.GetImage',
    index=1,
    containing_service=None,
    input_type=_GETIMAGEREQUEST,
    output_type=_GETIMAGERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Verify',
    full_name='finger.Finger.Verify',
    index=2,
    containing_service=None,
    input_type=_VERIFYREQUEST,
    output_type=_VERIFYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='finger.Finger.GetConfig',
    index=3,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='finger.Finger.SetConfig',
    index=4,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='finger.Finger.SetConfigMulti',
    index=5,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FINGER)

DESCRIPTOR.services_by_name['Finger'] = _FINGER

# @@protoc_insertion_point(module_scope)
